@@ -54,6 +54,7 @@ static bool irda_discover_device(GSM_StateMachine *state, int *fd)
     	int			s, z, len, i;
     	GSM_DateTime		Date;
     	bool			founddevice = false;
+	int deviceid;
 #ifdef WIN32
 	int			index;
 #endif
@@ -75,22 +76,25 @@ static bool irda_discover_device(GSM_StateMachine *state, int *fd)
 
 			if (getsockopt(*fd, SOL_IRLMP, IRLMP_ENUMDEVICES, buf, &s) == 0) {
 		    		for (i = 0; i < (int)list->numDevice; i++) {
-					dbgprintf("Irda: found device \"%s\" (address %d) - ",
-							list->Device[i].irdaDeviceName,
+
 #ifdef WIN32
-							(list->Device[i].irdaDeviceID[0] << 24) |
+					deviceid = (list->Device[i].irdaDeviceID[0] << 24) |
 							(list->Device[i].irdaDeviceID[1] << 16) |
 							(list->Device[i].irdaDeviceID[2] << 8) |
-							(list->Device[i].irdaDeviceID[3])
+							(list->Device[i].irdaDeviceID[3]);
 #else
-							list->Device[i].irdaDeviceID
+					deviceid = list->Device[i].irdaDeviceID;
 #endif
+					dbgprintf("Irda: found device \"%s\" (address %d) - ",
+							list->Device[i].irdaDeviceName,
+							deviceid
 							);
-					if (strcmp(GetModelData(NULL,NULL,list->Device[i].irdaDeviceName)->number,"") != 0) {
+					if (strcmp(GetModelData(state, NULL,NULL,list->Device[i].irdaDeviceName)->number,"") != 0) {
 						founddevice = true;
 						/* Model AUTO */
-						if (state->CurrentConfig->Model[0]==0) strcpy(state->Phone.Data.Model,GetModelData(NULL,NULL,list->Device[i].irdaDeviceName)->number);
-						state->Phone.Data.ModelInfo = GetModelData(NULL,state->Phone.Data.Model,NULL);
+						if (state->CurrentConfig->Model[0]==0) 
+							strcpy(state->Phone.Data.Model,GetModelData(state, NULL,NULL,list->Device[i].irdaDeviceName)->number);
+						state->Phone.Data.ModelInfo = GetModelData(state, NULL,state->Phone.Data.Model,NULL);
 					}
 					if (founddevice) {
 			    			dbgprintf("correct\n");
