@@ -180,8 +180,8 @@ static GSM_Error serial_open (GSM_StateMachine *s)
 	if (d->hPhone < 0) {
 		i = errno;
 		GSM_OSErrorInfo(s,"open in serial_open");
-		if (i == ENOENT) return ERR_DEVICENOTEXIST;		//no such file or directory
-		if (i == EACCES) return ERR_DEVICENOPERMISSION;	//permission denied
+		if (i == ENOENT) return ERR_DEVICENOTEXIST;		/* no such file or directory */
+		if (i == EACCES) return ERR_DEVICENOPERMISSION;	/* permission denied */
 		return ERR_DEVICEOPENERROR;
 	}
 
@@ -261,6 +261,8 @@ static GSM_Error serial_setdtrrts(GSM_StateMachine *s, bool dtr, bool rts)
     	struct termios	  	t;
     	unsigned int	    	flags;
 
+	if (s->SkipDtrRts) return ERR_NONE;
+
 	assert(d->hPhone >= 0);
 
     	if (tcgetattr(d->hPhone, &t)) {
@@ -296,13 +298,21 @@ static GSM_Error serial_setdtrrts(GSM_StateMachine *s, bool dtr, bool rts)
     	flags = 0;
     	ioctl(d->hPhone, TIOCMGET, &flags);
 
-    	dbgprintf("Serial device:");
-    	dbgprintf(" DTR is %s",       flags&TIOCM_DTR?"up":"down");
-    	dbgprintf(", RTS is %s",      flags&TIOCM_RTS?"up":"down");
-    	dbgprintf(", CAR is %s",      flags&TIOCM_CAR?"up":"down");
-    	dbgprintf(", CTS is %s\n",    flags&TIOCM_CTS?"up":"down");
-    	if (((flags&TIOCM_DTR)==TIOCM_DTR) != dtr) return ERR_DEVICEDTRRTSERROR;
-    	if (((flags&TIOCM_RTS)==TIOCM_RTS) != rts) return ERR_DEVICEDTRRTSERROR;
+    	smprintf(s, "Serial device:");
+    	smprintf(s, " DTR is %s",       flags & TIOCM_DTR ? "up" : "down");
+    	smprintf(s, ", RTS is %s",      flags & TIOCM_RTS ? "up" : "down");
+    	smprintf(s, ", CAR is %s",      flags & TIOCM_CAR ? "up" : "down");
+    	smprintf(s, ", CTS is %s\n",    flags & TIOCM_CTS ? "up" : "down");
+
+    	if (((flags & TIOCM_DTR) == TIOCM_DTR) != dtr) {
+		smprintf(s, "HINT: Setting DTR failed, maybe adding -nodtr to connection will help you.\n");
+		return ERR_DEVICEDTRRTSERROR;
+	}
+
+    	if (((flags & TIOCM_RTS) == TIOCM_RTS) != rts) {
+		smprintf(s, "HINT: Setting RTS failed, maybe adding -nodtr to connection will help you.\n");
+		return ERR_DEVICEDTRRTSERROR;
+	}
 
     	return ERR_NONE;
 }
@@ -313,6 +323,7 @@ static GSM_Error serial_setspeed(GSM_StateMachine *s, int speed)
     	struct termios  	t;
 	baud_record		*curr = baud_table;
 
+	if (s->SkipDtrRts) return ERR_NONE;
 
 	assert(d->hPhone >= 0);
 
@@ -360,7 +371,6 @@ static int serial_read(GSM_StateMachine *s, void *buf, size_t nbytes)
     	FD_SET(d->hPhone, &readfds);
 
     	timeout2.tv_sec     = 0;
-//    	timeout2.tv_usec    = 1;
     	timeout2.tv_usec    = 50000;
 
     	if (select(d->hPhone+1, &readfds, NULL, NULL, &timeout2)) {
@@ -375,11 +385,12 @@ static int serial_write(GSM_StateMachine *s, const void *buf, size_t nbytes)
     	GSM_Device_SerialData   *d = &s->Device.Data.Serial;
     	int		     	ret;
     	size_t		  	actual = 0;
+	const unsigned char *buffer = (const unsigned char *)buf; /* Just to have correct type */
 
 	assert(d->hPhone >= 0);
 
     	do {
-		ret = write(d->hPhone, (unsigned char *)buf, nbytes - actual);
+		ret = write(d->hPhone, buffer, nbytes - actual);
 		if (ret < 0) {
 			if (errno == EAGAIN) {
 				my_sleep(1);
@@ -389,7 +400,7 @@ static int serial_write(GSM_StateMachine *s, const void *buf, size_t nbytes)
 	    		return actual;
 		}
 		actual  += ret;
-		buf     += ret;
+		buffer  += ret;
     		if (s->ConnectionType == GCT_FBUS2PL2303) my_sleep(1);
     	} while (actual < nbytes);
     	return actual;
