@@ -90,7 +90,7 @@ GSM_FeatureName AllFeatureNames[] = {
 	{"SMS_ME", F_SMS_ME},
 	{"XLNK", F_XLNK},
 	{"SUBMIT_SIM_ONLY", F_SUBMIT_SIM_ONLY},
-	{"PBK_UCS2", F_PBK_UCS2},
+	{"PBK_UNICODE", F_PBK_UNICODE},
 	{"SQWE", F_SQWE},
 	{"NO_ATOBEX", F_NO_ATOBEX},
 	{"LENGTH_BYTES", F_LENGTH_BYTES},
@@ -235,6 +235,10 @@ OnePhoneModel allmodels[] = {
 	{"3595" ,"NPM-10" ,"",		{0}},/* irda? */
 #endif
 #if defined(GSM_ENABLE_NOKIA6510) || defined(GSM_ENABLE_ATGEN)
+	{"1110i","RM-93" ,"Nokia 1110i",{F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* guess */
+	{"2125i","RH-71" ,"Nokia 2125i",{F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* guess */
+	{"1600", "RH-64" ,"Nokia 1600",{F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* guess */
+	{"2610", "RH-87" ,"Nokia 2610",{F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* guess */
 	{"3109c","RM-274","Nokia 3109c",{F_SERIES40_30,F_PBKTONEGAL,F_TODO66,F_PBKSMSLIST,F_PBKUSER,F_NOTES,F_CHAT,F_SYNCML,F_FILES2,0}},/* guess */
 	{"3110c","RM-237","Nokia 3110c",{F_SERIES40_30,F_PBKTONEGAL,F_TODO66,F_PBKSMSLIST,F_PBKUSER,F_NOTES,F_CHAT,F_SYNCML,F_FILES2,0}},/* guess */
 	{"3220" ,"RH-37" ,"",           {F_PBKTONEGAL,F_TODO66,F_PBKSMSLIST,F_PBKUSER,F_WAPMMSPROXY,F_NOTES,F_SYNCML,F_FILES2,F_3220_MMS,0}},
@@ -250,15 +254,17 @@ OnePhoneModel allmodels[] = {
 	{"5310" ,"RM-303","Nokia 5310", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* guess */
 	{"6020" ,"RM-30" ,"Nokia 6020", {F_VOICETAGS, F_FILES2, F_CHAT, F_WAPMMSPROXY, F_TODO66, F_PBKTONEGAL, F_NOTES,0}},/* guess */
 	{"6021" ,"RM-94" ,"Nokia 6021", {F_PBKTONEGAL,F_TODO66,F_PBKSMSLIST,F_PBKUSER,F_WAPMMSPROXY,F_NOTES,F_CHAT,F_SYNCML,F_FILES2,F_6230iWAP,F_6230iCALLER,0}},/* guess */
-	{"6030" ,"RM-74" ,"Nokia 6030", {F_VOICETAGS, F_FILES2, F_CHAT, F_WAPMMSPROXY, F_TODO66, F_PBKTONEGAL, F_NOTES, F_NOFILE1,0}},/* guess */
+	{"6030" ,"RM-74" ,"Nokia 6030", {F_VOICETAGS, F_FILES2, F_CHAT, F_WAPMMSPROXY, F_TODO66, F_PBKTONEGAL, F_NOTES, F_NOFILE1, F_RADIO,0}},/* guess */
 	{"6030b","RM-75" ,"Nokia 6030b",{F_VOICETAGS, F_FILES2, F_CHAT, F_WAPMMSPROXY, F_TODO66, F_PBKTONEGAL, F_NOTES, F_NOFILE1,0}},/* guess */
 	{"6030" ,"RM-225","Nokia 6030", {F_VOICETAGS, F_FILES2, F_CHAT, F_WAPMMSPROXY, F_TODO66, F_PBKTONEGAL, F_NOTES, F_NOFILE1,0}},/* guess */
 	{"6070" ,"RM-166","Nokia 6070", {F_PBKTONEGAL,F_TODO66,F_PBKSMSLIST,F_PBKUSER,F_WAPMMSPROXY,F_NOTES,F_CHAT,F_SYNCML,F_FILES2,0}},
+	{"6070" ,"RM-167","Nokia 6070", {F_SERIES40_30,F_PBKTONEGAL,F_TODO66,F_PBKSMSLIST,F_PBKUSER,F_WAPMMSPROXY,F_NOTES,F_CHAT,F_SYNCML,F_FILES2,0}},
 	{"6085" ,"RM-198","Nokia 6085", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* fixme */
 	{"6086" ,"RM-260","Nokia 6086", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* fixme */
 	{"6086" ,"RM-188","Nokia 6086", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* fixme */
 	{"6100" ,"NPL-2" ,"Nokia 6100", {F_PBKTONEGAL,F_TODO66,0}},
 	{"6101" ,"RM-76" ,"Nokia 6101", {F_PBKTONEGAL,F_TODO66,0}},
+	{"6101" ,"RM-77" ,"Nokia 6101", {F_SERIES40_30,F_PBKTONEGAL,F_TODO66,F_PBKSMSLIST,F_PBKUSER,F_RADIO,F_SYNCML,F_FILES2,F_PROFILES,F_VOICETAGS,F_NOTES,F_PBKIMG,0}},
 	{"6103" ,"RM-161","Nokia 6103", {F_PBKTONEGAL,F_TODO66,F_RADIO,F_NOFILE1,0}},/* fixme */
 	{"6102i","RM-162","Nokia 6102i",{F_PBKTONEGAL,F_TODO66,F_RADIO,F_NOFILE1,0}},/* fixme */
 	{"6111" ,"RM-82" ,"Nokia 6111", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},
@@ -280,6 +286,7 @@ OnePhoneModel allmodels[] = {
 	{"6310" ,"NPE-4" ,"Nokia 6310", {F_TODO63,F_CAL65,F_NOMIDI,F_NOMMS,F_VOICETAGS,0}},
 	{"6310i","NPL-1" ,"Nokia 6310i",{F_TODO63,F_CAL65,F_NOMIDI,F_BLUETOOTH,F_NOMMS,F_VOICETAGS,F_PROFILES,0}},
 	{"6385" ,"NHP-2AX","Nokia 6385",{F_TODO63,F_CAL65,F_NOMIDI,F_NOMMS,F_VOICETAGS,0}},
+	{"6500c","RM-265","Nokia 6500c", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* fixme */
 	{"6510" ,"NPM-9" ,"Nokia 6510", {F_TODO63,F_CAL65,F_NOMIDI,F_RADIO,F_NOFILESYSTEM,F_NOMMS,F_VOICETAGS,0}},
 	{"6610" ,"NHL-4U","Nokia 6610", {F_PBKTONEGAL,F_TODO66,F_RADIO,0}},
 	{"6610i","RM-37" ,"Nokia 6610i",{F_PBKTONEGAL,F_TODO66,F_RADIO,F_SYNCML,0}},
@@ -531,6 +538,7 @@ OnePhoneModel allmodels[] = {
 	{"Z320i",	"AAB-1022091-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"Z250i/Z250c",	"AAB-1022092-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"T658c",	"AAB-1022101-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"W380i",	"AAB-1022111-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"K530c",	"AAB-1022131-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"T616",	"AAB-1031011-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"T637",	"AAB-1031012-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
@@ -541,6 +549,7 @@ OnePhoneModel allmodels[] = {
 	{"Z310a",	"AAB-1032021-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"Z320a",	"AAB-1032041-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"Z250a",	"AAB-1032042-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"W380a",	"AAB-1032051-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"Z520i/Z520c",	"AAC-1052011-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"Z520a",	"AAC-1052012-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"Z525i",	"AAC-1052013-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
@@ -574,6 +583,8 @@ OnePhoneModel allmodels[] = {
 	{"K630i",	"AAD-3022101-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"V640i",	"AAD-3022102-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"W910i",	"AAD-3052021-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"W890i",	"AAD-3052041-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"K660i",	"AAD-3052071-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"K850i",	"AAD-3252011-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"Z750i",	"AAD-3252022-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"Z750a",	"AAD-3252023-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
@@ -607,6 +618,7 @@ OnePhoneModel allmodels[] = {
 	{"W950i",	"FAD-3022013-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"P1i",		"FAD-3022015-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"W960i",	"FAD-3022017-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"GC95",	"FAD-3031011-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"GC99",	"FAD-3031012-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"PC300",	"FAD-3231011-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"GC79",	"FAE-1021011-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, F_SMS_LOCATION_0, 0}},
@@ -633,12 +645,14 @@ OnePhoneModel allmodels[] = {
 	{"M341i",	"M7", "MT170",					   {F_OBEX, F_IRMC_LEVEL_2, 0}},
 
 	/* Motorola */
-	{"W5",		"W5", "",					   {F_OBEX, F_IRMC_LEVEL_2, F_MODE22, 0}},
-	{"V3",		"V3 Razr", "",					   {F_OBEX, F_IRMC_LEVEL_2, F_MODE22, 0}},
-	{"L6",		"L6", "",					   {F_OBEX, F_IRMC_LEVEL_2, F_MODE22, 0}},
-	{"Serias E",	"Serias E",	"",				   {F_OBEX, F_IRMC_LEVEL_2, F_MODE22, 0}},
-	{"E815m",	"E815m",	"",				   {F_OBEX, F_IRMC_LEVEL_2, F_MODE22, 0}},
+	{"W5",		"W5", "",					   {F_OBEX, F_IRMC_LEVEL_2, F_MODE22, F_PBK_UNICODE, 0}},
+	{"V3",		"V3 Razr", "",					   {F_OBEX, F_IRMC_LEVEL_2, F_MODE22, F_PBK_UNICODE, 0}},
+	{"L6",		"L6", "",					   {F_OBEX, F_IRMC_LEVEL_2, F_MODE22, F_PBK_UNICODE, 0}},
+	{"Serias E",	"Serias E",	"",				   {F_OBEX, F_IRMC_LEVEL_2, F_MODE22, F_PBK_UNICODE, 0}},
+	{"E815m",	"E815m",	"",				   {F_OBEX, F_IRMC_LEVEL_2, F_MODE22, F_PBK_UNICODE, 0}},
+	{"V635",	"V635",	"",					   {F_OBEX, F_IRMC_LEVEL_2, F_MODE22, F_PBK_UNICODE, 0}},
 	{"L7",		"L7", "",					   {F_CKPD_NO_UNICODE, 0}},
+	{"RAZRV3x",	"RAZRV3x",	"",				   {F_OBEX, F_IRMC_LEVEL_2, F_MODE22, F_PBK_UNICODE, 0}},
 
 	/* Sharp */
 	{"GX",		"GX Series", "",				   {F_OBEX, F_XLNK, 0}},
