@@ -79,6 +79,7 @@ static const GSM_ConnectionInfo GSM_Connections[] = {
 	{"bluephonet", GCT_BLUEPHONET, false},
 	{"blueat", GCT_BLUEAT, false},
 	{"bluerfobex", GCT_BLUEOBEX, false},
+	{"bluefbus", GCT_BLUEFBUS2, false},
 	{"bluerffbus", GCT_BLUEFBUS2, false},
 	{"bluerfphonet", GCT_BLUEPHONET, false},
 	{"bluerfat", GCT_BLUEAT, false},
@@ -290,6 +291,15 @@ GSM_Error GSM_RegisterAllPhoneModules(GSM_StateMachine *s)
 			return ERR_NONE;
 		}
 #endif
+
+		/* With GNAPgen and auto model we can work with unknown models too */
+#ifdef GSM_ENABLE_GNAPGEN
+		if (s->ConnectionType == GCT_BLUEGNAPBUS || s->ConnectionType == GCT_IRDAGNAPBUS) {
+			smprintf(s,"[Module           - \"%s\"]\n",GNAPGENPhone.models);
+			s->Phone.Functions = &GNAPGENPhone;
+			return ERR_NONE;
+		}
+#endif
 		if (model->model[0] == 0) return ERR_UNKNOWNMODELSTRING;
 	}
 	s->Phone.Functions=NULL;
@@ -369,6 +379,34 @@ GSM_Error GSM_OpenConnection(GSM_StateMachine *s)
 	return ERR_NONE;
 }
 
+/**
+ * Internal function which just closes connection and cleans up structures.
+ */
+GSM_Error GSM_CloseConnection(GSM_StateMachine *s)
+{
+	GSM_Error error;
+
+	smprintf(s,"[Closing]\n");
+
+	error=s->Protocol.Functions->Terminate(s);
+	if (error!=ERR_NONE) return error;
+
+	error = s->Device.Functions->CloseDevice(s);
+	if (error!=ERR_NONE) return error;
+
+	if (s->LockFile!=NULL) unlock_device(&(s->LockFile));
+
+	s->Phone.Data.ModelInfo		  = NULL;
+	s->Phone.Data.Manufacturer[0]	  = 0;
+	s->Phone.Data.Model[0]		  = 0;
+	s->Phone.Data.Version[0]	  = 0;
+	s->Phone.Data.VerDate[0]	  = 0;
+	s->Phone.Data.VerNum		  = 0;
+
+	return ERR_NONE;
+}
+
+
 /**
  * Tries to read model using configured phone connection.
  */
@@ -481,8 +519,11 @@ GSM_Error GSM_InitConnection(GSM_StateMachine *s, int ReplyNum)
 		s->di 				  = di;
 		s->di.use_global 		  = s->CurrentConfig->UseGlobalDebugFile;
 		GSM_SetDebugLevel(s->CurrentConfig->DebugLevel, &s->di);
-		error=GSM_SetDebugFile(s->CurrentConfig->DebugFile, &s->di);
-		if (error != ERR_NONE) return error;
+		error = GSM_SetDebugFile(s->CurrentConfig->DebugFile, &s->di);
+		if (error != ERR_NONE) {
+			GSM_LogError(s, "Init:GSM_SetDebugFile" , error);
+			return error;
+		}
 
 		smprintf_level(s, D_ERROR, "[Gammu            - %s built %s %s using %s]\n",
 				VERSION,
@@ -507,24 +548,31 @@ GSM_Error GSM_InitConnection(GSM_StateMachine *s, int ReplyNum)
 			smprintf(s,"%s",VERSION);
 		}
 
-		error=GSM_RegisterAllConnections(s, s->CurrentConfig->Connection);
-		if (error!=ERR_NONE) return error;
+		error = GSM_RegisterAllConnections(s, s->CurrentConfig->Connection);
+		if (error != ERR_NONE) {
+			GSM_LogError(s, "Init:GSM_RegisterAllConnections" , error);
+			return error;
+		}
 
 autodetect:
 		/* Model auto */
 		if (s->CurrentConfig->Model[0] == 0) {
 			error = GSM_TryGetModel(s);
-			if (i != s->ConfigNum - 1) {
-				if (error == ERR_DEVICEOPENERROR) 	continue;
-				if (error == ERR_DEVICELOCKED) 	 	continue;
-				if (error == ERR_DEVICENOTEXIST)  	continue;
-				if (error == ERR_DEVICEBUSY) 		continue;
-				if (error == ERR_DEVICENOPERMISSION) 	continue;
-				if (error == ERR_DEVICENODRIVER) 	continue;
-				if (error == ERR_DEVICENOTWORK) 	continue;
-				if (error == ERR_TIMEOUT)	 	continue;
+			if ((i != s->ConfigNum - 1) && (
+				(error == ERR_DEVICEOPENERROR) ||
+				(error == ERR_DEVICELOCKED) ||
+				(error == ERR_DEVICENOTEXIST) ||
+				(error == ERR_DEVICEBUSY) ||
+				(error == ERR_DEVICENOPERMISSION) ||
+				(error == ERR_DEVICENODRIVER) ||
+				(error == ERR_DEVICENOTWORK))) {
+				GSM_CloseConnection(s);
+				continue;
+			}
+			if (error != ERR_NONE) {
+				GSM_LogError(s, "Init:GSM_TryGetModel" , error);
+				return error;
 			}
-			if (error != ERR_NONE) return error;
 		}
 
 		/* Switching to "correct" module */
@@ -536,27 +584,41 @@ autodetect:
 			s->CurrentConfig->Model[0] = 0;
 			goto autodetect;
 		}
-		if (error != ERR_NONE) return error;
+		if (error != ERR_NONE) {
+			GSM_LogError(s, "Init:GSM_RegisterAllPhoneModules" , error);
+			return error;
+		}
 
 		/* We didn't open device earlier ? Make it now */
 		if (!s->opened) {
 			error = GSM_OpenConnection(s);
-			if (i != s->ConfigNum - 1) {
-				if (error == ERR_DEVICEOPENERROR) 	continue;
-				if (error == ERR_DEVICELOCKED) 	 	continue;
-				if (error == ERR_DEVICENOTEXIST)  	continue;
-				if (error == ERR_DEVICEBUSY) 		continue;
-				if (error == ERR_DEVICENOPERMISSION) 	continue;
-				if (error == ERR_DEVICENODRIVER) 	continue;
-				if (error == ERR_DEVICENOTWORK) 	continue;
+			if ((i != s->ConfigNum - 1) && (
+				(error == ERR_DEVICEOPENERROR) ||
+				(error == ERR_DEVICELOCKED) ||
+				(error == ERR_DEVICENOTEXIST) ||
+				(error == ERR_DEVICEBUSY) ||
+				(error == ERR_DEVICENOPERMISSION) ||
+				(error == ERR_DEVICENODRIVER) ||
+				(error == ERR_DEVICENOTWORK))) {
+				GSM_CloseConnection(s);
+				continue;
+			}
+			if (error != ERR_NONE) {
+				GSM_LogError(s, "Init:GSM_OpenConnection" , error);
+				return error;
 			}
-			if (error != ERR_NONE) return error;
 		}
 
 		/* Initialize phone layer */
 		error=s->Phone.Functions->Initialise(s);
-		if (error == ERR_TIMEOUT && i != s->ConfigNum - 1) continue;
-		if (error != ERR_NONE) return error;
+		if (error == ERR_TIMEOUT && i != s->ConfigNum - 1) {
+			GSM_CloseConnection(s);
+			continue;
+		}
+		if (error != ERR_NONE) {
+			GSM_LogError(s, "Init:Phone->Initialise" , error);
+			return error;
+		}
 
 		if (strcasecmp(s->CurrentConfig->StartInfo,"yes") == 0) {
 			s->Phone.Functions->ShowStartInfo(s,true);
@@ -570,15 +632,28 @@ autodetect:
 
 		/* For debug it's good to have firmware and real model version and manufacturer */
 		error=s->Phone.Functions->GetManufacturer(s);
-		if (error == ERR_TIMEOUT && i != s->ConfigNum - 1) continue;
-		if (error != ERR_NONE) return error;
+		if (error == ERR_TIMEOUT && i != s->ConfigNum - 1) {
+			GSM_CloseConnection(s);
+			continue;
+		}
+		if (error != ERR_NONE) {
+			GSM_LogError(s, "Init:Phone->GetManufacturer" , error);
+			return error;
+		}
 
 		error=s->Phone.Functions->GetModel(s);
-		if (error != ERR_NONE) return error;
+		if (error != ERR_NONE) {
+			GSM_LogError(s, "Init:Phone->GetModel" , error);
+			return error;
+		}
 
 		error=s->Phone.Functions->GetFirmware(s);
-		if (error != ERR_NONE) return error;
+		if (error != ERR_NONE) {
+			GSM_LogError(s, "Init:Phone->GetFirmware" , error);
+			return error;
+		}
 
+		smprintf(s,"[Connected]\n");
 		return ERR_NONE;
 	}
 	return ERR_UNCONFIGURED;
@@ -614,7 +689,7 @@ GSM_Error GSM_TerminateConnection(GSM_StateMachine *s)
 
 	if (!s->opened) return ERR_UNKNOWN;
 
-	smprintf(s,"[Closing]\n");
+	smprintf(s,"[Terminating]\n");
 
 	if (strcasecmp(s->CurrentConfig->StartInfo,"yes") == 0) {
 		if (s->Phone.Data.StartInfoCounter > 0) s->Phone.Functions->ShowStartInfo(s,false);
@@ -625,20 +700,8 @@ GSM_Error GSM_TerminateConnection(GSM_StateMachine *s)
 		if (error!=ERR_NONE) return error;
 	}
 
-	error=s->Protocol.Functions->Terminate(s);
-	if (error!=ERR_NONE) return error;
-
-	error = s->Device.Functions->CloseDevice(s);
-	if (error!=ERR_NONE) return error;
-
-	s->Phone.Data.ModelInfo		  = NULL;
-	s->Phone.Data.Manufacturer[0]	  = 0;
-	s->Phone.Data.Model[0]		  = 0;
-	s->Phone.Data.Version[0]	  = 0;
-	s->Phone.Data.VerDate[0]	  = 0;
-	s->Phone.Data.VerNum		  = 0;
-
-	if (s->LockFile!=NULL) unlock_device(&(s->LockFile));
+	error = GSM_CloseConnection(s);
+	if (error != ERR_NONE) return error;
 
 	if (!s->di.use_global && s->di.dl!=0 && fileno(s->di.df) != 1 && fileno(s->di.df) != 2) fclose(s->di.df);
 
@@ -669,7 +732,11 @@ GSM_Error GSM_WaitForOnce(GSM_StateMachine *s, unsigned const char *buffer,
 		}
 
 		/* Some data received. Reset timer */
-		if (GSM_ReadDevice(s,true)!=0) i=0;
+		if (GSM_ReadDevice(s, true) != 0) {
+			i = 0;
+		} else {
+			my_sleep(10);
+		}
 
 		if (length != 0) {
 			free (sentmsg.Buffer);
@@ -870,6 +937,9 @@ GSM_Error GSM_FindGammuRC (INI_Section **result)
 	}
 
 #if defined(WIN32)
+	/* Reset as we're using strcat */
+	configfile[0] = 0;
+
 	/* This makes sense only on Windows */
 	envpath = getenv("HOMEDRIVE");
 	if (envpath) {
