@@ -7,9 +7,7 @@
  */
 
 /**
- * @defgroup StateMachine State machine data
- *
- * This module implements core of state machine.
+ * \addtogroup StateMachine
  *
  * @{
  */
@@ -26,6 +24,8 @@
 #include <gammu-security.h>
 #include <gammu-callback.h>
 #include <gammu-settings.h>
+#include <gammu-misc.h>
+#include <gammu-category.h>
 
 typedef struct _GSM_User	 	GSM_User;
 typedef struct _GSM_Reply_Function	GSM_Reply_Function;
@@ -513,6 +513,7 @@ typedef enum {
 	ID_DeleteFolder,
 	ID_DeleteFile,
 	ID_ModeSwitch,
+	ID_GetProtocol,
 #ifdef GSM_ENABLE_ALCATEL
     	/* AT mode */
     	ID_SetFlowControl,
@@ -573,15 +574,15 @@ typedef struct {
 	/**
 	 * Phone IMEI (or serial number).
 	 */
-	char			IMEI[GSM_MAX_IMEI_LENGTH];
+	char			IMEI[GSM_MAX_IMEI_LENGTH + 1];
 	/**
 	 * Phone manufacturer as reported by phone.
 	 */
-	char			Manufacturer[GSM_MAX_MANUFACTURER_LENGTH];
+	char			Manufacturer[GSM_MAX_MANUFACTURER_LENGTH + 1];
 	/**
 	 * Phone model as reported by phone.
 	 */
-	char			Model[GSM_MAX_MODEL_LENGTH];
+	char			Model[GSM_MAX_MODEL_LENGTH + 1];
 	/**
 	 * Model information, pointer to static @ref allmodels array.
 	 */
@@ -590,11 +591,11 @@ typedef struct {
 	 * Phone version as reported by phone. It doesn't have to be numerical
 	 * at all.
 	 */
-	char			Version[GSM_MAX_VERSION_LENGTH];
+	char			Version[GSM_MAX_VERSION_LENGTH + 1];
 	/**
 	 * Phone version date, might be empty for some models.
 	 */
-	char			VerDate[GSM_MAX_VERSION_DATE_LENGTH];
+	char			VerDate[GSM_MAX_VERSION_DATE_LENGTH + 1];
 	/**
 	 * Phone version as number, if applicable.
 	 */
@@ -661,7 +662,7 @@ typedef struct {
 	/**
 	 * Used internally by phone drivers.
 	 */
-	int                 	*VoiceRecord;
+	size_t                 	*VoiceRecord;
 	/**
 	 * Used internally by phone drivers.
 	 */
@@ -879,7 +880,7 @@ struct _GSM_Reply_Function {
 	 * Which character of message should be checked as subtype. Zero to
 	 * disable subtype checking.
 	 */
-	int			subtypechar;
+	size_t			subtypechar;
 	/**
 	 * Subtype to be checked.
 	 */
@@ -974,11 +975,11 @@ typedef struct {
 	/**
 	 * Reads alarm set in phone.
 	 */
-	GSM_Error (*GetAlarm)	   	(GSM_StateMachine *s, GSM_Alarm	*alarm);
+	GSM_Error (*GetAlarm)	   	(GSM_StateMachine *s, GSM_Alarm	*Alarm);
 	/**
 	 * Sets alarm in phone.
 	 */
-	GSM_Error (*SetAlarm)	   	(GSM_StateMachine *s, GSM_Alarm *alarm);
+	GSM_Error (*SetAlarm)	   	(GSM_StateMachine *s, GSM_Alarm *Alarm);
 	/**
 	 * Gets locale from phone.
 	 */
@@ -1530,6 +1531,14 @@ struct _GSM_User {
 
 struct _GSM_StateMachine {
 	GSM_ConnectionType 	ConnectionType;				/**< Type of connection as int			*/
+	/**
+	 * Skip lowlevel serial handling, cable is known to be broken.
+	 */
+	bool			SkipDtrRts;
+	/**
+	 * Do not give power supply to cable on DTR/RTS signals.
+	 */
+	bool			NoPowerCable;
 	char			*LockFile;				/**< Lock file name for Unix 			*/
 	GSM_Debug_Info		di;					/**< Debug information				*/
 	bool			opened;					/**< Is connection opened ?			*/
@@ -1547,24 +1556,28 @@ struct _GSM_StateMachine {
 
 /* ------------------------ Other general definitions ---------------------- */
 
+/**
+ * Tries to register all modules to find one matching current configuration.
+ *
+ * \param s State machine pointer.
+ *
+ * \return Error code, ERR_NONE on success.
+ */
 GSM_Error GSM_RegisterAllPhoneModules	(GSM_StateMachine *s);
 
-GSM_Error GSM_InitConnection		(GSM_StateMachine *s, int ReplyNum);
-GSM_Error GSM_TerminateConnection	(GSM_StateMachine *s);
-
-int 	  GSM_ReadDevice		(GSM_StateMachine *s, bool wait);
-
 GSM_Error GSM_WaitForOnce		(GSM_StateMachine *s, unsigned const char *buffer,
-			  		 int length, unsigned char type, int time);
+			  		 int length, unsigned char type, int timeout);
 
 GSM_Error GSM_WaitFor			(GSM_StateMachine *s, unsigned const char *buffer,
-		       			 int length, unsigned char type, int time,
-					 GSM_Phone_RequestID request);
+		       			 int length, unsigned char type, int timeout,
+					 GSM_Phone_RequestID request) WARNUNUSED;
 
 GSM_Error GSM_DispatchMessage		(GSM_StateMachine *s);
 
 void 	  GSM_DumpMessageLevel2		(GSM_StateMachine *s, unsigned const char *message, int messagesize, int type);
+void 	  GSM_DumpMessageLevel2Recv	(GSM_StateMachine *s, unsigned const char *message, int messagesize, int type);
 void 	  GSM_DumpMessageLevel3		(GSM_StateMachine *s, unsigned const char *message, int messagesize, int type);
+void GSM_DumpMessageLevel3Recv(GSM_StateMachine *s, unsigned const char *message, int messagesize, int type);
 
 
 void GSM_OSErrorInfo(GSM_StateMachine *s, char *description);
