@@ -70,13 +70,13 @@ void		DecodeISO88591QuotedPrintable	(unsigned char *dest, const unsigned char *s
 void DecodeXMLUTF8(unsigned char *dest, const unsigned char *src, int len);
 
 /* ------------------------------- BASE64 ---------------------------------- */
-void 		EncodeBASE64			(const unsigned char *Input, unsigned char *Output, int Length);
-int 		DecodeBASE64			(const unsigned char *Input, unsigned char *Output, int Length);
+void 		EncodeBASE64			(const unsigned char *Input, unsigned char *Output, size_t Length);
+int 		DecodeBASE64			(const unsigned char *Input, unsigned char *Output, size_t Length);
 
 /* ---------------------- DefaultAlphabet for SMS -------------------------- */
-void 		EncodeDefault			(unsigned char *dest, const unsigned char *src, int *len, bool UseExtensions, unsigned char *ExtraAlphabet);
-void		DecodeDefault			(unsigned char *dest, const unsigned char *src, int len, bool UseExtensions,  unsigned char *ExtraAlphabet);
-void 		FindDefaultAlphabetLen		(const unsigned char *src, int *srclen, int *smslen, int maxlen);
+void 		EncodeDefault			(unsigned char *dest, const unsigned char *src, size_t *len, bool UseExtensions, unsigned char *ExtraAlphabet);
+void		DecodeDefault			(unsigned char *dest, const unsigned char *src, size_t len, bool UseExtensions,  unsigned char *ExtraAlphabet);
+void 		FindDefaultAlphabetLen		(const unsigned char *src, size_t *srclen, size_t *smslen, size_t maxlen);
 
 int GSM_PackSevenBitsToEight	(int offset, unsigned char *input, unsigned char *output, int length);
 int GSM_UnpackEightBitsToSeven	(int offset, int in_length, int out_length,
@@ -110,38 +110,40 @@ int		GSM_PackSemiOctetNumber		(unsigned char *Number, unsigned char *Output, boo
 
 /* ---------------------------- Bits --------------------------------------- */
 
-void BufferAlign      (unsigned char *Destination, int *CurrentBit);
-void BufferAlignNumber(int *CurrentBit);
+void BufferAlign      (unsigned char *Destination, size_t *CurrentBit);
+void BufferAlignNumber(size_t *CurrentBit);
 
-void AddBuffer	  (unsigned char *Destination, int *CurrentBit, unsigned char *Source, int BitsToProcess);
-void AddBufferByte(unsigned char *Destination, int *CurrentBit, unsigned char Source, int BitsToProcess);
+void AddBuffer	  (unsigned char *Destination, size_t *CurrentBit, unsigned char *Source, size_t BitsToProcess);
+void AddBufferByte(unsigned char *Destination, size_t *CurrentBit, unsigned char Source, size_t BitsToProcess);
 
-void GetBuffer    (unsigned char *Source, int *CurrentBit, unsigned char *Destination, int BitsToProcess);
-void GetBufferInt (unsigned char *Source, int *CurrentBit, int *integer, int BitsToProcess);
-void GetBufferI   (unsigned char *Source, int *CurrentBit, int *result, int BitsToProcess);
+void GetBuffer    (unsigned char *Source, size_t *CurrentBit, unsigned char *Destination, size_t BitsToProcess);
+void GetBufferInt (unsigned char *Source, size_t *CurrentBit, int *integer, size_t BitsToProcess);
+void GetBufferI   (unsigned char *Source, size_t *CurrentBit, int *result, size_t BitsToProcess);
 
-int GetBit   (unsigned char *Buffer, int BitNum);
-int SetBit   (unsigned char *Buffer, int BitNum);
-int ClearBit (unsigned char *Buffer, int BitNum);
+int GetBit   (unsigned char *Buffer, size_t BitNum);
+int SetBit   (unsigned char *Buffer, size_t BitNum);
+int ClearBit (unsigned char *Buffer, size_t BitNum);
 
 /* ---------------------------- Other -------------------------------------- */
 
 void StringToDouble	(char *text, double *d);
 
+#ifndef HAVE_STRCHRNUL
+extern char *strchrnul(char *s, int find);
+#endif
 #ifndef HAVE_STRNCASECMP
+#define TOLOWER(Ch) (isupper (Ch) ? tolower (Ch) : (Ch))
 extern int strncasecmp (const char *s1, const char *s2, size_t n);
 #endif
 #ifndef HAVE_STRCASECMP
 extern int strcasecmp (const char *s1, const char *s2);
 #endif
-#ifndef HAVE_STRCHRNUL
-extern char *strchrnul(char *s, int find);
-#endif
+
 
 /**
  * Gets line from buffer.
  *
- * @param MergeLines: Determine whether merge lines as vCard style 
+ * @param MergeLines: Determine whether merge lines as vCard style
  * continuation or quoted printable continutaion.
  * @param Buffer: Data source to parse.
  * @param Pos: Current position in data.
