@@ -15,7 +15,10 @@
 
 #ifndef atgen_motorola_h
 #define atgen_motorola_h
+
 #include <gammu-config.h>
+#include "../../gsmcomon.h"
+#include "../../protocol/protocol.h"
 
 #ifdef GSM_ENABLE_ATGEN
 
@@ -29,6 +32,11 @@
  */
 GSM_Error MOTOROLA_SetMode(GSM_StateMachine *s, const char *command);
 
+/**
+ * Catches +MBAN: reply and sets Mode according to it.
+ */
+GSM_Error MOTOROLA_Banner(GSM_Protocol_Message msg, GSM_StateMachine *s);
+
 #endif
 #endif
 
