@@ -117,6 +117,10 @@ GSM_Error ATOBEX_SetOBEXMode(GSM_StateMachine *s, OBEX_Service service)
 			/* Sharp extension */
 			error = GSM_WaitFor (s, "AT+XLNK\r", 8, 0x00, 4, ID_SetOBEX);
 			break;
+		case ATOBEX_OBEX_SQWE:
+			/* Siemens extension */
+			error = GSM_WaitFor (s, "AT^SQWE=3\r", 10, 0x00, 4, ID_SetOBEX);
+			break;
 		case ATOBEX_OBEX_None:
 			break;
 	}
@@ -168,6 +172,7 @@ GSM_Error ATOBEX_Initialise(GSM_StateMachine *s)
 	GSM_Error		error;
 
 	Priv->Mode				= ATOBEX_ModeAT;
+	Priv->EBCAFailed = false;
 
 	/* We might receive incoming event */
 	s->Phone.Data.BatteryCharge = NULL;
@@ -189,6 +194,10 @@ GSM_Error ATOBEX_Initialise(GSM_StateMachine *s)
 		Priv->HasOBEX = ATOBEX_OBEX_MODE22;
 	} else if (GSM_IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_XLNK)) {
 		Priv->HasOBEX = ATOBEX_OBEX_XLNK;
+	} else if (GSM_IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_SQWE)) {
+		Priv->HasOBEX = ATOBEX_OBEX_SQWE;
+	} else if (GSM_IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_CPROT)) {
+		Priv->HasOBEX = ATOBEX_OBEX_CPROT0;
 	} else {
 		if (PrivAT->Mode) {
 			smprintf(s, "Guessed mode style switching\n");
@@ -532,20 +541,20 @@ GSM_Error ATOBEX_GetManufacturer(GSM_StateMachine *s)
 	return ATGEN_GetManufacturer(s);
 }
 
-GSM_Error ATOBEX_GetAlarm(GSM_StateMachine *s, GSM_Alarm *alarm)
+GSM_Error ATOBEX_GetAlarm(GSM_StateMachine *s, GSM_Alarm *Alarm)
 {
 	GSM_Error error;
 
 	if ((error = ATOBEX_SetATMode(s))!= ERR_NONE) return error;
-	return ATGEN_GetAlarm(s, alarm);
+	return ATGEN_GetAlarm(s, Alarm);
 }
 
-GSM_Error ATOBEX_SetAlarm(GSM_StateMachine *s, GSM_Alarm *alarm)
+GSM_Error ATOBEX_SetAlarm(GSM_StateMachine *s, GSM_Alarm *Alarm)
 {
 	GSM_Error error;
 
 	if ((error = ATOBEX_SetATMode(s))!= ERR_NONE) return error;
-	return ATGEN_SetAlarm(s, alarm);
+	return ATGEN_SetAlarm(s, Alarm);
 }
 
 GSM_Error ATOBEX_SetIncomingUSSD(GSM_StateMachine *s, bool enable)
@@ -655,12 +664,14 @@ GSM_Error ATOBEX_GetMemoryStatus(GSM_StateMachine *s, GSM_MemoryStatus *Status)
 	GSM_Error 		error;
 
 	if (Status->MemoryType == MEM_ME) {
-		if ((error = ATOBEX_SetOBEXMode(s, OBEX_IRMC))!= ERR_NONE) return error;
+		if ((error = ATOBEX_SetOBEXMode(s, OBEX_IRMC))!= ERR_NONE)
+			goto atgen;
 		return OBEXGEN_GetMemoryStatus(s, Status);
-	} else {
-		if ((error = ATOBEX_SetATMode(s))!= ERR_NONE) return error;
-		return ATGEN_GetMemoryStatus(s, Status);
 	}
+
+atgen:
+	if ((error = ATOBEX_SetATMode(s))!= ERR_NONE) return error;
+	return ATGEN_GetMemoryStatus(s, Status);
 }
 
 GSM_Error ATOBEX_GetMemory(GSM_StateMachine *s, GSM_MemoryEntry *entry)
@@ -668,12 +679,14 @@ GSM_Error ATOBEX_GetMemory(GSM_StateMachine *s, GSM_MemoryEntry *entry)
 	GSM_Error 		error;
 
 	if (entry->MemoryType == MEM_ME) {
-		if ((error = ATOBEX_SetOBEXMode(s, OBEX_IRMC))!= ERR_NONE) return error;
+		if ((error = ATOBEX_SetOBEXMode(s, OBEX_IRMC))!= ERR_NONE)
+			goto atgen;
 		return OBEXGEN_GetMemory(s, entry);
-	} else {
-		if ((error = ATOBEX_SetATMode(s))!= ERR_NONE) return error;
-		return ATGEN_GetMemory(s, entry);
 	}
+
+atgen:
+	if ((error = ATOBEX_SetATMode(s))!= ERR_NONE) return error;
+	return ATGEN_GetMemory(s, entry);
 }
 
 GSM_Error ATOBEX_GetNextMemory(GSM_StateMachine *s, GSM_MemoryEntry *entry, bool start)
@@ -681,12 +694,14 @@ GSM_Error ATOBEX_GetNextMemory(GSM_StateMachine *s, GSM_MemoryEntry *entry, bool
 	GSM_Error 		error;
 
 	if (entry->MemoryType == MEM_ME) {
-		if ((error = ATOBEX_SetOBEXMode(s, OBEX_IRMC))!= ERR_NONE) return error;
+		if ((error = ATOBEX_SetOBEXMode(s, OBEX_IRMC))!= ERR_NONE)
+			goto atgen;
 		return OBEXGEN_GetNextMemory(s, entry, start);
-	} else {
-		if ((error = ATOBEX_SetATMode(s))!= ERR_NONE) return error;
-		return ATGEN_GetNextMemory(s, entry, start);
 	}
+
+atgen:
+	if ((error = ATOBEX_SetATMode(s))!= ERR_NONE) return error;
+	return ATGEN_GetNextMemory(s, entry, start);
 }
 
 GSM_Error ATOBEX_SetMemory(GSM_StateMachine *s, GSM_MemoryEntry *entry)
@@ -694,12 +709,14 @@ GSM_Error ATOBEX_SetMemory(GSM_StateMachine *s, GSM_MemoryEntry *entry)
 	GSM_Error 		error;
 
 	if (entry->MemoryType == MEM_ME) {
-		if ((error = ATOBEX_SetOBEXMode(s, OBEX_IRMC))!= ERR_NONE) return error;
+		if ((error = ATOBEX_SetOBEXMode(s, OBEX_IRMC))!= ERR_NONE)
+			goto atgen;
 		return OBEXGEN_SetMemory(s, entry);
-	} else {
-		if ((error = ATOBEX_SetATMode(s))!= ERR_NONE) return error;
-		return ATGEN_SetMemory(s, entry);
 	}
+
+atgen:
+	if ((error = ATOBEX_SetATMode(s))!= ERR_NONE) return error;
+	return ATGEN_SetMemory(s, entry);
 }
 
 GSM_Error ATOBEX_AddMemory(GSM_StateMachine *s, GSM_MemoryEntry *entry)
@@ -707,12 +724,14 @@ GSM_Error ATOBEX_AddMemory(GSM_StateMachine *s, GSM_MemoryEntry *entry)
 	GSM_Error 		error;
 
 	if (entry->MemoryType == MEM_ME) {
-		if ((error = ATOBEX_SetOBEXMode(s, OBEX_IRMC))!= ERR_NONE) return error;
+		if ((error = ATOBEX_SetOBEXMode(s, OBEX_IRMC))!= ERR_NONE)
+			goto atgen;
 		return OBEXGEN_AddMemory(s, entry);
-	} else {
-		if ((error = ATOBEX_SetATMode(s))!= ERR_NONE) return error;
-		return ATGEN_AddMemory(s, entry);
 	}
+
+atgen:
+	if ((error = ATOBEX_SetATMode(s))!= ERR_NONE) return error;
+	return ATGEN_AddMemory(s, entry);
 }
 
 GSM_Error ATOBEX_DeleteMemory(GSM_StateMachine *s, GSM_MemoryEntry *entry)
@@ -720,12 +739,14 @@ GSM_Error ATOBEX_DeleteMemory(GSM_StateMachine *s, GSM_MemoryEntry *entry)
 	GSM_Error 		error;
 
 	if (entry->MemoryType == MEM_ME) {
-		if ((error = ATOBEX_SetOBEXMode(s, OBEX_IRMC))!= ERR_NONE) return error;
+		if ((error = ATOBEX_SetOBEXMode(s, OBEX_IRMC))!= ERR_NONE)
+			goto atgen;
 		return OBEXGEN_DeleteMemory(s, entry);
-	} else {
-		if ((error = ATOBEX_SetATMode(s))!= ERR_NONE) return error;
-		return ATGEN_DeleteMemory(s, entry);
 	}
+
+atgen:
+	if ((error = ATOBEX_SetATMode(s))!= ERR_NONE) return error;
+	return ATGEN_DeleteMemory(s, entry);
 }
 
 GSM_Error ATOBEX_DeleteAllMemory(GSM_StateMachine *s, GSM_MemoryType type)
@@ -733,12 +754,14 @@ GSM_Error ATOBEX_DeleteAllMemory(GSM_StateMachine *s, GSM_MemoryType type)
 	GSM_Error 		error;
 
 	if (type == MEM_ME) {
-		if ((error = ATOBEX_SetOBEXMode(s, OBEX_IRMC))!= ERR_NONE) return error;
+		if ((error = ATOBEX_SetOBEXMode(s, OBEX_IRMC))!= ERR_NONE)
+			goto atgen;
 		return OBEXGEN_DeleteAllMemory(s, type);
-	} else {
-		if ((error = ATOBEX_SetATMode(s))!= ERR_NONE) return error;
-		return ATGEN_DeleteAllMemory(s, type);
 	}
+
+atgen:
+	if ((error = ATOBEX_SetATMode(s))!= ERR_NONE) return error;
+	return ATGEN_DeleteAllMemory(s, type);
 }
 
 /*@}*/
@@ -1071,7 +1094,7 @@ GSM_Error ATOBEX_ReplyGetFileSystemStatus(GSM_Protocol_Message msg, GSM_StateMac
 	switch (s->Phone.Data.Priv.ATGEN.ReplyState) {
 		case AT_Reply_OK:
 			error = ATGEN_ParseReply(s,
-					GetLineString(msg.Buffer, s->Phone.Data.Priv.ATGEN.Lines, 2),
+					GetLineString(msg.Buffer, &s->Phone.Data.Priv.ATGEN.Lines, 2),
 					"*EMEM: @i, @i, @i, @i, @i",
 					&s->Phone.Data.FileSystemStatus->Free,
 					&s->Phone.Data.FileSystemStatus->Used,
@@ -1264,17 +1287,23 @@ GSM_Error ATOBEX_ReplyGetBatteryCharge(GSM_Protocol_Message msg, GSM_StateMachin
 
 GSM_Error ATOBEX_GetBatteryCharge(GSM_StateMachine *s, GSM_BatteryCharge *bat)
 {
-	GSM_Error error;
+	GSM_Error error, error2;
 	int	i = 0;
+	GSM_Phone_ATOBEXData	*Priv = &s->Phone.Data.Priv.ATOBEX;
 
 	s->Phone.Data.BatteryCharge = bat;
 
 	if ((error = ATOBEX_SetATMode(s))!= ERR_NONE) return error;
 
+	/* Go to AT if EBCA does not work */
+	if (Priv->EBCAFailed) {
+		return ATGEN_GetBatteryCharge(s, bat);
+	}
 
 	/* Now try ericsson extended reporting */
 	error = GSM_WaitFor (s, "AT*EBCA=1\r", 10, 0x00, 3, ID_GetBatteryCharge);
 	if (error != ERR_NONE) {
+		Priv->EBCAFailed = true;
 		/* Ty ATGEN state */
 		return ATGEN_GetBatteryCharge(s, bat);
 	}
@@ -1289,7 +1318,10 @@ GSM_Error ATOBEX_GetBatteryCharge(GSM_StateMachine *s, GSM_BatteryCharge *bat)
 		i++;
 	}
 	/* Disable reading information */
-	GSM_WaitFor (s, "AT*EBCA=0\r", 10, 0x00, 3, ID_GetBatteryCharge);
+	error2 = GSM_WaitFor (s, "AT*EBCA=0\r", 10, 0x00, 3, ID_GetBatteryCharge);
+	if (error2 != ERR_NONE) {
+		return error;
+	}
 	/* If something failed, do AT way */
 	if (error != ERR_NONE) {
 		return ATGEN_GetBatteryCharge(s, bat);
