@@ -325,13 +325,13 @@ GSM_Error DCT3_ReplyGetAlarm(GSM_Protocol_Message msg, GSM_StateMachine *s)
 	return ERR_EMPTY;
 }
 
-GSM_Error DCT3_GetAlarm(GSM_StateMachine *s, GSM_Alarm *alarm, unsigned char msgtype)
+GSM_Error DCT3_GetAlarm(GSM_StateMachine *s, GSM_Alarm *Alarm, unsigned char msgtype)
 {
 	unsigned char req[] = {N6110_FRAME_HEADER, 0x6d};
 
-	if (alarm->Location!=1) return ERR_NOTSUPPORTED;
+	if (Alarm->Location!=1) return ERR_NOTSUPPORTED;
 
-	s->Phone.Data.Alarm=alarm;
+	s->Phone.Data.Alarm=Alarm;
 	smprintf(s, "Getting alarm\n");
 	return GSM_WaitFor (s, req, 4, msgtype, 4, ID_GetAlarm);
 }
@@ -373,7 +373,7 @@ GSM_Error DCT3_ReplySetAlarm(GSM_Protocol_Message msg, GSM_StateMachine *s)
 	return ERR_UNKNOWN;
 }
 
-GSM_Error DCT3_SetAlarm(GSM_StateMachine *s, GSM_Alarm *alarm, unsigned char msgtype)
+GSM_Error DCT3_SetAlarm(GSM_StateMachine *s, GSM_Alarm *Alarm, unsigned char msgtype)
 {
 	unsigned char req[] = {N6110_FRAME_HEADER, 0x6b, 0x01, 0x20, 0x03,
 			       0x02,      /* Unknown. Not for enabling/disabling */
@@ -381,15 +381,21 @@ GSM_Error DCT3_SetAlarm(GSM_StateMachine *s, GSM_Alarm *alarm, unsigned char msg
 			       0x00,	  /* Minute 				 */
 			       0x00};	  /* Unknown. Not seconds 		 */
 
-	if (alarm->Location != 1) return ERR_NOTSUPPORTED;
+	if (Alarm->Location != 1) return ERR_NOTSUPPORTED;
 
-	req[8] = alarm->DateTime.Hour;
-	req[9] = alarm->DateTime.Minute;
+	req[8] = Alarm->DateTime.Hour;
+	req[9] = Alarm->DateTime.Minute;
 
 	smprintf(s, "Setting alarm\n");
 	return GSM_WaitFor (s, req, 11, msgtype, 4, ID_SetAlarm);
 }
 
+GSM_Error DCT3_ReplyWaitSMSC(GSM_Protocol_Message msg UNUSED, GSM_StateMachine *s)
+{
+	smprintf(s, "Waiting for SMSC reply\n");
+	return ERR_NONE;
+}
+
 GSM_Error DCT3_ReplyGetSMSC(GSM_Protocol_Message msg, GSM_StateMachine *s)
 {
 	int 		i;
@@ -673,7 +679,7 @@ GSM_Error DCT3_SetWAPBookmark(GSM_StateMachine *s, GSM_WAPBookmark *bookmark)
 GSM_Error DCT3_ReplyGetWAPSettings(GSM_Protocol_Message msg, GSM_StateMachine *s)
 {
 	int 			tmp,Number;
-//	int			tmp2;
+/* 	int			tmp2; */
 	GSM_Phone_Data		*Data = &s->Phone.Data;
 #ifdef GSM_ENABLE_NOKIA6110
 	GSM_Phone_N6110Data 	*Priv6110 = &s->Phone.Data.Priv.N6110;
@@ -713,9 +719,9 @@ GSM_Error DCT3_ReplyGetWAPSettings(GSM_Protocol_Message msg, GSM_StateMachine *s
 		if (msg.Buffer[tmp+13] == 0x01) Data->WAPSettings->Settings[0].IsSecurity = true;
 
 		/* I'm not sure here. Experimental values from 6210 5.56 */
-//		tmp2 = DecodeUnicodeLength(Data->WAPSettings->Settings[0].Title);
-//		if (tmp2 != 0) tmp2 --;
-//		tmp2 += tmp;
+/* 		tmp2 = DecodeUnicodeLength(Data->WAPSettings->Settings[0].Title); */
+/* 		if (tmp2 != 0) tmp2 --; */
+/* 		tmp2 += tmp; */
 		if (!(UnicodeLength(Data->WAPSettings->Settings[0].Title)) % 2) tmp++;
 		if (UnicodeLength(Data->WAPSettings->Settings[0].HomePage)!=0) tmp++;
 
@@ -736,11 +742,11 @@ GSM_Error DCT3_ReplyGetWAPSettings(GSM_Protocol_Message msg, GSM_StateMachine *s
 			Priv7110->WAPLocations.Locations[2] 	= msg.Buffer[tmp+10];
 			Priv7110->WAPLocations.Locations[3] 	= msg.Buffer[tmp+11];
 
-//			Priv7110->WAPLocations.CurrentLocation	= msg.Buffer[tmp2+1];
-//			Priv7110->WAPLocations.Locations[0] 	= msg.Buffer[tmp2+3];
-//			Priv7110->WAPLocations.Locations[1] 	= msg.Buffer[tmp2+4];
-//			Priv7110->WAPLocations.Locations[2] 	= msg.Buffer[tmp2+5];
-//			Priv7110->WAPLocations.Locations[3] 	= msg.Buffer[tmp2+6];
+/* 			Priv7110->WAPLocations.CurrentLocation	= msg.Buffer[tmp2+1]; */
+/* 			Priv7110->WAPLocations.Locations[0] 	= msg.Buffer[tmp2+3]; */
+/* 			Priv7110->WAPLocations.Locations[1] 	= msg.Buffer[tmp2+4]; */
+/* 			Priv7110->WAPLocations.Locations[2] 	= msg.Buffer[tmp2+5]; */
+/* 			Priv7110->WAPLocations.Locations[3] 	= msg.Buffer[tmp2+6]; */
 		}
 #endif
 #ifdef GSM_ENABLE_NOKIA6110
