@@ -31,14 +31,14 @@
 #include "n7110.h"
 #include "dct3func.h"
 
-static GSM_Error N7110_GetAlarm(GSM_StateMachine *s, GSM_Alarm *alarm)
+static GSM_Error N7110_GetAlarm(GSM_StateMachine *s, GSM_Alarm *Alarm)
 {
-	return DCT3_GetAlarm(s, alarm, 0x19);
+	return DCT3_GetAlarm(s, Alarm, 0x19);
 }
 
-static GSM_Error N7110_SetAlarm(GSM_StateMachine *s, GSM_Alarm *alarm)
+static GSM_Error N7110_SetAlarm(GSM_StateMachine *s, GSM_Alarm *Alarm)
 {
-	return DCT3_SetAlarm(s, alarm, 0x19);
+	return DCT3_SetAlarm(s, Alarm, 0x19);
 }
 
 static GSM_Error N7110_ReplyGetMemory(GSM_Protocol_Message msg, GSM_StateMachine *s)
@@ -46,13 +46,11 @@ static GSM_Error N7110_ReplyGetMemory(GSM_Protocol_Message msg, GSM_StateMachine
 	GSM_Phone_Data *Data = &s->Phone.Data;
 
 	smprintf(s, "Phonebook entry received\n");
-	switch (msg.Buffer[6]) {
-	case 0x0f:
+
+	if (msg.Buffer[6] == 0x0f)
 		return N71_65_ReplyGetMemoryError(msg.Buffer[10], s);
-	default:
-		return N71_65_DecodePhonebook(s, Data->Memory,Data->Bitmap,Data->SpeedDial,msg.Buffer+18,msg.Length-18,false);
-	}
-	return ERR_UNKNOWN;
+
+	return N71_65_DecodePhonebook(s, Data->Memory,Data->Bitmap,Data->SpeedDial,msg.Buffer+18,msg.Length-18,false);
 }
 
 static GSM_Error N7110_GetMemory (GSM_StateMachine *s, GSM_MemoryEntry *entry)
@@ -249,7 +247,7 @@ static GSM_SMSMessageLayout N7110_SMSTemplate = {
 static GSM_Error N7110_ReplyGetSMSMessage(GSM_Protocol_Message msg, GSM_StateMachine *s)
 {
 	int			i;
-	int			Width, Height;
+	size_t			Width, Height;
 	unsigned char		output[500], output2[500];
 	GSM_Phone_Data		*Data = &s->Phone.Data;
 
@@ -489,7 +487,8 @@ static int N7110_ReturnBinaryRingtoneLocation(char *model)
 
 static GSM_Error N7110_ReplyGetRingtone(GSM_Protocol_Message msg, GSM_StateMachine *s)
 {
-	int			tmp,i;
+	int			tmp;
+	size_t i;
 	GSM_Phone_Data		*Data = &s->Phone.Data;
 
 	smprintf(s, "Ringtone received\n");
@@ -664,7 +663,7 @@ static GSM_Error N7110_SetRingtone(GSM_StateMachine *s, GSM_Ringtone *Ringtone,
 	GSM_Ringtone	dest;
 	GSM_Error	error;
 	GSM_NetworkInfo	NetInfo;
-	int		size=200;
+	size_t		size=200;
 	unsigned char	req[1000] = {0x7C, 0x01, 0x00, 0x0D, 0x00,
 				     0x00, 0x00, 0x00, 0x00, 0x00,
 				     0x00};	  	/*Length*/
@@ -856,7 +855,8 @@ static GSM_Error N7110_ReplySetOperatorLogo(GSM_Protocol_Message msg UNUSED, GSM
 
 static GSM_Error N7110_SetCallerLogo(GSM_StateMachine *s, GSM_Bitmap *bitmap)
 {
-	int		block=0, i, Width, Height;
+	int		block=0, i;
+	size_t Width, Height;
 	unsigned int 	count = 18;
 	char		string[500];
 	unsigned char   req[500] = {N6110_FRAME_HEADER, 0x0b, 0x00,
@@ -869,7 +869,7 @@ static GSM_Error N7110_SetCallerLogo(GSM_StateMachine *s, GSM_Bitmap *bitmap)
 
 	/* Enabling/disabling logo */
 	if (bitmap->DefaultBitmap) {
-		string[0] = 0; //disabling
+		string[0] = 0; /* disabling */
 	} else {
 		string[0] = bitmap->BitmapEnabled?1:0;
 	}
@@ -927,7 +927,8 @@ static GSM_Error N7110_SetPictureImage(GSM_StateMachine *s, GSM_Bitmap *Bitmap)
 {
 	unsigned char		folder;
 	GSM_Error		error;
-	int			location, i, count, Width, Height;
+	int			location, i, count;
+	size_t Width, Height;
 	GSM_Phone_Bitmap_Types	Type = GSM_NokiaPictureImage;
 	unsigned char 		req[500] = {N6110_FRAME_HEADER, 0x50, 0x07,
 					    0x00,	/* location	*/
@@ -1000,7 +1001,7 @@ static GSM_Error N7110_SetBitmap(GSM_StateMachine *s, GSM_Bitmap *Bitmap)
 {
 	GSM_Error		error;
 	GSM_Phone_Bitmap_Types	Type;
-	int			Width, Height, i;
+	size_t			Width, Height, i;
 	unsigned char reqStartup[1000] = {N7110_FRAME_HEADER, 0xec,
 		0x15,			/* Startup Logo setting */
 		0x00, 0x00, 0x00, 0x04, 0xc0, 0x02, 0x00,
@@ -1104,7 +1105,8 @@ static GSM_Error N7110_DeleteMemory(GSM_StateMachine *s, GSM_MemoryEntry *entry)
 
 static GSM_Error N7110_SetMemory(GSM_StateMachine *s, GSM_MemoryEntry *entry)
 {
-	int 		count = 18, blocks;
+	int 		count = 18;
+	size_t blocks;
 	unsigned char 	req[5000] = {N7110_FRAME_HEADER, 0x0b, 0x00,
 				    0x01, 0x01, 0x00, 0x00, 0x0c,
 				    0x00, 0x00,		/* memory type	*/
@@ -1378,7 +1380,7 @@ static GSM_Error N7110_ReplyGetCalendarNotePos(GSM_Protocol_Message msg, GSM_Sta
 static GSM_Error N7110_GetNextCalendar(GSM_StateMachine *s,  GSM_CalendarEntry *Note, bool start)
 {
 	return N71_65_GetNextCalendar1(s,Note,start,&s->Phone.Data.Priv.N7110.LastCalendar,&s->Phone.Data.Priv.N7110.LastCalendarYear,&s->Phone.Data.Priv.N7110.LastCalendarPos);
-//	return N71_65_GetNextCalendar2(s,Note,start,&s->Phone.Data.Priv.N7110.LastCalendarYear,&s->Phone.Data.Priv.N7110.LastCalendarPos);
+/* 	return N71_65_GetNextCalendar2(s,Note,start,&s->Phone.Data.Priv.N7110.LastCalendarYear,&s->Phone.Data.Priv.N7110.LastCalendarPos); */
 }
 
 static GSM_Error N7110_GetCalendarStatus(GSM_StateMachine *s, GSM_CalendarStatus *Status)
@@ -1396,12 +1398,12 @@ static GSM_Error N7110_GetCalendarStatus(GSM_StateMachine *s, GSM_CalendarStatus
 	return ERR_NONE;
 
     	/* Method 2 */
-//	return GE_NOTSUPPORTED;
+/* 	return GE_NOTSUPPORTED; */
 }
 
 static GSM_Error N7110_AddCalendar(GSM_StateMachine *s, GSM_CalendarEntry *Note)
 {
-//	return N71_65_AddCalendar1(s, Note, NULL);
+/* 	return N71_65_AddCalendar1(s, Note, NULL); */
 	return N71_65_AddCalendar2(s,Note);
 }
 
@@ -1415,24 +1417,27 @@ static GSM_Error N7110_SetIncomingCall(GSM_StateMachine *s, bool enable)
 {
 #ifndef GSM_ENABLE_N71_92INCOMINGINFO
 	return ERR_SOURCENOTAVAILABLE;
-#endif
+#else
 	return NOKIA_SetIncomingCall(s,enable);
+#endif
 }
 
 static GSM_Error N7110_SetIncomingUSSD(GSM_StateMachine *s, bool enable)
 {
 #ifndef GSM_ENABLE_N71_92INCOMINGINFO
 	return ERR_SOURCENOTAVAILABLE;
-#endif
+#else
 	return NOKIA_SetIncomingUSSD(s,enable);
+#endif
 }
 
 static GSM_Error N7110_SetIncomingSMS(GSM_StateMachine *s, bool enable)
 {
 #ifndef GSM_ENABLE_N71_92INCOMINGINFO
 	return ERR_SOURCENOTAVAILABLE;
-#endif
+#else
 	return NOKIA_SetIncomingSMS(s,enable);
+#endif
 }
 
 GSM_Error N7110_AnswerCall(GSM_StateMachine *s, int ID, bool all)
