@@ -1526,7 +1526,11 @@ GSM_Error N71_65_ReplyGetMemoryError(unsigned char error, GSM_StateMachine *s)
 	case 0x3B: /* Tim Dreessen, 6230 */
 		smprintf(s, "Empty location\n");
 		s->Phone.Data.Memory->EntriesNum = 0;
-		return ERR_EMPTY;
+		/*
+		 * This is really empty, but this entry is calculated to
+		 * entries count, so we must return something.
+		 */
+		return ERR_NONE;
 	default:
 		smprintf(s, "ERROR: unknown %i\n",error);
 		return ERR_UNKNOWNRESPONSE;
