@@ -46,6 +46,20 @@ typedef enum {
 	OBEX_BrowsingFolders,
 } OBEX_Service;
 
+/**
+ * Description of what is IrMC end point able to do.
+ */
+typedef struct {
+	/**
+	 * Information Exchange Level.
+	 */
+	int IEL;
+	/**
+	 * Support for hard deletes?
+	 */
+	bool HD;
+} IRMC_Capability;
+
 typedef struct {
 	int				FilesLocationsUsed;
 	int				FilesLocationsCurrent;
@@ -67,6 +81,14 @@ typedef struct {
 	 * Offsets of entries in phonebook data
 	 */
 	int				*PbOffsets;
+	/**
+	 * Index - location translation map for phonebook
+	 */
+	int				*PbIndex;
+	/**
+	 * Number of entries in PbIndex list.
+	 */
+	int				PbIndexCount;
 	/**
 	 * LUID - location translation map for phonebook
 	 */
@@ -80,9 +102,9 @@ typedef struct {
 	 */
 	bool				UpdatePbLUID;
 	/**
-	 * Information Exchange Level for phonebook.
+	 * Capabilities for phonebook.
 	 */
-	int				PbIEL;
+	IRMC_Capability			PbCap;
 	/**
 	 * Complete phonebook data.
 	 */
@@ -99,6 +121,14 @@ typedef struct {
 	 * Offsets of todo entries in calendar data
 	 */
 	int				*TodoOffsets;
+	/**
+	 * Index - location translation map for todo
+	 */
+	int				*TodoIndex;
+	/**
+	 * Number of entries in TodoIndex list.
+	 */
+	int				TodoIndexCount;
 	/**
 	 * LUID - location translation map for todo
 	 */
@@ -123,6 +153,14 @@ typedef struct {
 	 * Offsets of calendar entries in calendar data
 	 */
 	int				*CalOffsets;
+	/**
+	 * Index - location translation map for calendar
+	 */
+	int				*CalIndex;
+	/**
+	 * Number of entries in CalIndex list.
+	 */
+	int				CalIndexCount;
 	/**
 	 * LUID - location translation map for calendar
 	 */
@@ -136,9 +174,9 @@ typedef struct {
 	 */
 	bool				UpdateCalLUID;
 	/**
-	 * Information Exchange Level for calendar.
+	 * Capabilities for calendar.
 	 */
-	int				CalIEL;
+	IRMC_Capability			CalCap;
 	/**
 	 * Complete calendar data.
 	 */
@@ -155,6 +193,14 @@ typedef struct {
 	 * Offsets of entries in note data
 	 */
 	int				*NoteOffsets;
+	/**
+	 * Index - location translation map for note
+	 */
+	int				*NoteIndex;
+	/**
+	 * Number of entries in NoteIndex list.
+	 */
+	int				NoteIndexCount;
 	/**
 	 * LUID - location translation map for note
 	 */
@@ -168,9 +214,9 @@ typedef struct {
 	 */
 	bool				UpdateNoteLUID;
 	/**
-	 * Information Exchange Level for note.
+	 * Capabilities for note.
 	 */
-	int				NoteIEL;
+	IRMC_Capability			NoteCap;
 	/**
 	 * Complete note data.
 	 */
