@@ -36,8 +36,8 @@ static GSM_Error FBUS2_WriteFrame(GSM_StateMachine 	*s,
 	buffer2[0] 	= FBUS2_FRAME_ID;
 	if (s->ConnectionType==GCT_FBUS2IRDA) buffer2[0] = FBUS2_IRDA_FRAME_ID;
 
-	buffer2[1] 	= FBUS2_DEVICE_PHONE;		//destination
-	buffer2[2]	= FBUS2_DEVICE_PC;		//source
+	buffer2[1] 	= FBUS2_DEVICE_PHONE;		/* destination */
+	buffer2[2]	= FBUS2_DEVICE_PC;		/* source */
 	buffer2[3]	= MsgType;
 	buffer2[4]	= MsgLength / 256;
 	buffer2[5]	= MsgLength % 256;
@@ -92,8 +92,8 @@ static GSM_Error FBUS2_WriteMessage (GSM_StateMachine 	*s,
 
 		GSM_DumpMessageLevel2(s, buffer2, thislength, MsgType);
 
-		error=FBUS2_WriteFrame(s, buffer2, thislength + 2, MsgType);
-		if (error!=ERR_NONE) return error;
+		error = FBUS2_WriteFrame(s, buffer2, thislength + 2, MsgType);
+		if (error != ERR_NONE) return error;
 	}
 
 	return ERR_NONE;
@@ -108,10 +108,9 @@ static GSM_Error FBUS2_SendAck(GSM_StateMachine 	*s,
 	buffer2[0] = MsgType;
 	buffer2[1] = MsgSequence;
 
-	if (s->di.dl==DL_TEXT || s->di.dl==DL_TEXTALL ||
-	    s->di.dl==DL_TEXTDATE || s->di.dl==DL_TEXTALLDATE) {
-		smprintf(s,"[Sending Ack of type %02x, seq %x]\n",buffer2[0],buffer2[1]);
-	}
+	smprintf_level(s, D_TEXT, "[Sending Ack of type %02x, seq %x]\n",
+			buffer2[0],
+			buffer2[1]);
 
 	/* Sending to phone */
 	return FBUS2_WriteFrame(s, buffer2, 2, FBUS2_ACK_BYTE);
@@ -135,10 +134,8 @@ static GSM_Error FBUS2_StateMachine(GSM_StateMachine *s, unsigned char rx_char)
 
 		/* Checksum is incorrect */
 		if (d->Msg.CheckSum[0] != d->Msg.CheckSum[1]) {
-			if (s->di.dl==DL_TEXT || s->di.dl==DL_TEXTALL || s->di.dl==DL_TEXTERROR ||
-			    s->di.dl==DL_TEXTDATE || s->di.dl==DL_TEXTALLDATE || s->di.dl==DL_TEXTERRORDATE) {
-				smprintf(s,"[ERROR: checksum]\n");
-			}
+			smprintf_level(s, D_ERROR, "[ERROR: checksum]\n");
+
 			free(d->Msg.Buffer);
 			d->Msg.Length 		= 0;
 			d->Msg.Buffer 		= NULL;
@@ -150,10 +147,9 @@ static GSM_Error FBUS2_StateMachine(GSM_StateMachine *s, unsigned char rx_char)
 		seq_num = d->Msg.Buffer[d->Msg.Length-1];
 
 		if (d->Msg.Type == FBUS2_ACK_BYTE) {
-			if (s->di.dl==DL_TEXT || s->di.dl==DL_TEXTALL ||
-			    s->di.dl==DL_TEXTDATE || s->di.dl==DL_TEXTALLDATE) {
-				smprintf(s, "[Received Ack of type %02x, seq %02x]\n",d->Msg.Buffer[0],seq_num);
-			}
+			smprintf_level(s, D_TEXT, "[Received Ack of type %02x, seq %02x]\n",
+					d->Msg.Buffer[0], seq_num);
+
 			free(d->Msg.Buffer);
 			d->Msg.Buffer 	= NULL;
 			d->Msg.Length 	= 0;
@@ -173,10 +169,7 @@ static GSM_Error FBUS2_StateMachine(GSM_StateMachine *s, unsigned char rx_char)
 		}
 
 		if ((seq_num & 0x40) != 0x40 && d->FramesToGo != frm_num) {
-			if (s->di.dl==DL_TEXT || s->di.dl==DL_TEXTALL || s->di.dl==DL_TEXTERROR ||
-			    s->di.dl==DL_TEXTDATE || s->di.dl==DL_TEXTALLDATE || s->di.dl==DL_TEXTERRORDATE) {
-				smprintf(s, "[ERROR: Missed part of multiframe msg]\n");
-			}
+			smprintf_level(s, D_ERROR, "[ERROR: Missed part of multiframe msg]\n");
 
 			free(d->Msg.Buffer);
 			d->Msg.Length 		= 0;
@@ -187,10 +180,7 @@ static GSM_Error FBUS2_StateMachine(GSM_StateMachine *s, unsigned char rx_char)
 		}
 
 		if ((seq_num & 0x40) != 0x40 && d->Msg.Type != d->MultiMsg.Type) {
-			if (s->di.dl==DL_TEXT || s->di.dl==DL_TEXTALL || s->di.dl==DL_TEXTERROR ||
-			    s->di.dl==DL_TEXTDATE || s->di.dl==DL_TEXTALLDATE || s->di.dl==DL_TEXTERRORDATE) {
-				smprintf(s, "[ERROR: Multiframe msg in multiframe msg]\n");
-			}
+			smprintf_level(s, D_ERROR, "[ERROR: Multiframe msg in multiframe msg]\n");
 
 			free(d->Msg.Buffer);
 			d->Msg.Length 		= 0;
@@ -245,10 +235,8 @@ static GSM_Error FBUS2_StateMachine(GSM_StateMachine *s, unsigned char rx_char)
 	}
 	if (d->MsgRXState == RX_GetSource) {
 		if (rx_char != FBUS2_DEVICE_PHONE) {
-			if (s->di.dl==DL_TEXT || s->di.dl==DL_TEXTALL || s->di.dl==DL_TEXTERROR ||
-			    s->di.dl==DL_TEXTDATE || s->di.dl==DL_TEXTALLDATE || s->di.dl==DL_TEXTERRORDATE) {
-				smprintf(s,"[ERROR: incorrect char - %02x, not %02x]\n", rx_char, FBUS2_DEVICE_PHONE);
-			}
+			smprintf_level(s, D_ERROR, "[ERROR: incorrect char - %02x, not %02x]\n",
+					rx_char, FBUS2_DEVICE_PHONE);
 
 			d->MsgRXState = RX_Sync;
 			return ERR_NONE;
@@ -260,10 +248,8 @@ static GSM_Error FBUS2_StateMachine(GSM_StateMachine *s, unsigned char rx_char)
 	}
 	if (d->MsgRXState == RX_GetDestination) {
 		if (rx_char != FBUS2_DEVICE_PC) {
-			if (s->di.dl==DL_TEXT || s->di.dl==DL_TEXTALL || s->di.dl==DL_TEXTERROR ||
-			    s->di.dl==DL_TEXTDATE || s->di.dl==DL_TEXTALLDATE || s->di.dl==DL_TEXTERRORDATE) {
-				    smprintf(s,"[ERROR: incorrect char - %02x, not %02x]\n", rx_char, FBUS2_DEVICE_PC);
-			}
+			smprintf_level(s, D_ERROR, "[ERROR: incorrect char - %02x, not %02x]\n",
+					rx_char, FBUS2_DEVICE_PC);
 
 			d->MsgRXState = RX_Sync;
 			return ERR_NONE;
@@ -278,13 +264,9 @@ static GSM_Error FBUS2_StateMachine(GSM_StateMachine *s, unsigned char rx_char)
 			case GCT_FBUS2:
 			case GCT_FBUS2DLR3:
 			case GCT_DKU5FBUS2:
-			case GCT_ARK3116FBUS2:
 			case GCT_FBUS2PL2303:
 			case GCT_FBUS2BLUE:
 			case GCT_BLUEFBUS2:
-			case GCT_DKU5FBUS2NODTR:
-			case GCT_FBUS2NODTR:
-			case GCT_FBUS2DLR3NODTR:
 				if (rx_char == FBUS2_FRAME_ID) correct = true;
 				break;
 			case GCT_FBUS2IRDA:
@@ -294,14 +276,9 @@ static GSM_Error FBUS2_StateMachine(GSM_StateMachine *s, unsigned char rx_char)
 				break;
 		}
 		if (!correct) {
-			if (s->di.dl==DL_TEXT || s->di.dl==DL_TEXTALL || s->di.dl==DL_TEXTERROR ||
-			    s->di.dl==DL_TEXTDATE || s->di.dl==DL_TEXTALLDATE || s->di.dl==DL_TEXTERRORDATE) {
-				if (s->ConnectionType==GCT_FBUS2IRDA) {
-					smprintf(s,"[ERROR: incorrect char - %02x, not %02x]\n", rx_char, FBUS2_IRDA_FRAME_ID);
-			    	} else {
-					smprintf(s,"[ERROR: incorrect char - %02x, not %02x]\n", rx_char, FBUS2_FRAME_ID);
-			    	}
-			}
+			smprintf_level(s, D_ERROR, "[ERROR: incorrect char - %02x, not %02x]\n",
+					rx_char,
+					(s->ConnectionType == GCT_FBUS2IRDA) ? FBUS2_IRDA_FRAME_ID : FBUS2_FRAME_ID);
 			return ERR_NONE;
 		}
 
@@ -316,36 +293,88 @@ static GSM_Error FBUS2_StateMachine(GSM_StateMachine *s, unsigned char rx_char)
 }
 
 #if defined(GSM_ENABLE_FBUS2DLR3) || defined(GSM_ENABLE_DKU5FBUS2) || defined(GSM_ENABLE_FBUS2BLUE) || defined(GSM_ENABLE_BLUEFBUS2) || defined(GSM_ENABLE_FBUS2PL2303)
-static void FBUS2_WriteDLR3(GSM_StateMachine *s, char *command, int length, int timeout)
+/**
+ * Writes (AT) command to device and reads reply.
+ *
+ * \todo This makes no reply parsing or error detection.
+ */
+static void FBUS2_WriteDLR3(GSM_StateMachine *s, const char *command, int length, int timeout)
 {
 	unsigned char		buff[300];
 	int			w = 0;
 	bool			wassomething = false;
+	int recvlen;
 
-	s->Device.Functions->WriteDevice(s,command,length);
 
-	for (w=0;w<timeout;w++) {
-		if (wassomething) {
-			if (s->Device.Functions->ReadDevice(s, buff, 255)==0) return;
-		} else {
-			if (s->Device.Functions->ReadDevice(s, buff, 255)>0) wassomething = true;
+	GSM_DumpMessageLevel2(s, command, length, 0xff);
+	s->Device.Functions->WriteDevice(s, command, length);
+
+	for (w = 0; w < timeout; w++) {
+		recvlen = s->Device.Functions->ReadDevice(s, buff, sizeof(buff) - 1);
+		if (wassomething && recvlen == 0) {
+			return;
+		} else if (recvlen > 0) {
+			GSM_DumpMessageLevel2Recv(s, buff, recvlen, 0xff);
+			wassomething = true;
 		}
 		my_sleep(50);
 	}
 }
+
+/**
+ * Performs switch to FBUS2 protocol using AT commands.
+ *
+ * \todo We should check return codes here.
+ */
+static GSM_Error FBUS2_ATSwitch(GSM_StateMachine *s)
+{
+	static const char init_1[] = "AT\r\n";
+	static const char init_2[] = "AT&F\r\n";
+	static const char init_3[] = "AT*NOKIAFBUS\r\n";
+
+	smprintf(s, "Switching to FBUS using AT commands\n");
+
+	FBUS2_WriteDLR3(s, init_1, strlen(init_1), 100);
+	FBUS2_WriteDLR3(s, init_2, strlen(init_2), 100);
+	FBUS2_WriteDLR3(s, init_3, strlen(init_3), 100);
+
+	return ERR_NONE;
+}
+
+/**
+ * Performs switch to FBUS2 protocol using AT commands.
+ *
+ * \todo We should check return codes here.
+ */
+static GSM_Error FBUS2_InitSequence(GSM_StateMachine *s)
+{
+	int count;
+	static const unsigned char init_char = 0x55;
+	static const unsigned char end_init_char = 0xc1;
+
+	for (count = 0; count < 32; count ++) {
+		if (s->Device.Functions->WriteDevice(s, &init_char, 1) != 1)
+			return ERR_DEVICEWRITEERROR;
+	}
+
+	if (s->Device.Functions->WriteDevice(s, &end_init_char, 1) != 1)
+		return ERR_DEVICEWRITEERROR;
+
+	my_sleep(1000);
+
+	return ERR_NONE;
+}
 #endif
 
 static GSM_Error FBUS2_Initialise(GSM_StateMachine *s)
 {
-	unsigned char		init_char	= 0x55;
 #ifdef GSM_ENABLE_FBUS2IRDA
-	unsigned char		end_init_char	= 0xc1;
 #endif
 
 	GSM_Protocol_FBUS2Data	*d		= &s->Protocol.Data.FBUS2;
 	GSM_Device_Functions	*Device 	= s->Device.Functions;
 	GSM_Error		error;
-	int			count;
+	unsigned char		buff[300];
 
 	d->Msg.Length		= 0;
 	d->Msg.Buffer		= NULL;
@@ -357,96 +386,67 @@ static GSM_Error FBUS2_Initialise(GSM_StateMachine *s)
 	d->FramesToGo		= 0;
 	d->MsgRXState		= RX_Sync;
 
-	error=Device->DeviceSetParity(s,false);
-	if (error!=ERR_NONE) return error;
+	error = Device->DeviceSetParity(s, false);
+	if (error != ERR_NONE) return error;
 
 	switch (s->ConnectionType) {
 #if defined(GSM_ENABLE_BLUEFBUS2) || defined(GSM_ENABLE_FBUS2BLUE)
 	case GCT_FBUS2BLUE:
 	case GCT_BLUEFBUS2:
-		FBUS2_WriteDLR3(s,"AT\r\n",		 4,10);
-		FBUS2_WriteDLR3(s,"AT&F\r\n",		 6,10);
-		FBUS2_WriteDLR3(s,"AT*NOKIAFBUS\r\n",	14,10);
+		error = FBUS2_ATSwitch(s);
+		if (error != ERR_NONE) return error;
 		break;
 #endif
 #if defined(GSM_ENABLE_FBUS2DLR3) || defined(GSM_ENABLE_DKU5FBUS2) || defined(GSM_ENABLE_FBUS2PL2303)
 	case GCT_DKU5FBUS2:
 	case GCT_FBUS2PL2303:
 	case GCT_FBUS2DLR3:
-	case GCT_ARK3116FBUS2:
-	case GCT_FBUS2DLR3NODTR:
-	case GCT_DKU5FBUS2NODTR:
-		if (s->ConnectionType != GCT_ARK3116FBUS2 &&
-				s->ConnectionType != GCT_DKU5FBUS2NODTR &&
-				s->ConnectionType != GCT_FBUS2DLR3NODTR
-				) {
-			error=Device->DeviceSetDtrRts(s,false,false);
-			if (error!=ERR_NONE) return error;
-			my_sleep(1000);
-
-			error=Device->DeviceSetDtrRts(s,true,true);
-			if (error!=ERR_NONE) return error;
-			error=Device->DeviceSetSpeed(s,19200);
-			if (error!=ERR_NONE) return error;
-		}
-
-		FBUS2_WriteDLR3(s,"AT\r\n",		 4,10);
-		FBUS2_WriteDLR3(s,"AT&F\r\n",		 6,10);
-		FBUS2_WriteDLR3(s,"AT*NOKIAFBUS\r\n",	14,10);
-
-		error=Device->CloseDevice(s);
-		if (error!=ERR_NONE) return error;
+		error = Device->DeviceSetDtrRts(s,false,false);
+		if (error != ERR_NONE) return error;
 		my_sleep(1000);
 
-		error=Device->OpenDevice(s);
-		if (error!=ERR_NONE) return error;
-		if (s->ConnectionType != GCT_ARK3116FBUS2 &&
-				s->ConnectionType != GCT_DKU5FBUS2NODTR &&
-				s->ConnectionType != GCT_FBUS2DLR3NODTR
-				) {
-			error=Device->DeviceSetParity(s,false);
-			if (error!=ERR_NONE) return error;
-			error=Device->DeviceSetSpeed(s,115200);
-			if (error!=ERR_NONE) return error;
-			error=Device->DeviceSetDtrRts(s,false,false);
-			if (error!=ERR_NONE) return error;
+		if (! s->NoPowerCable) {
+			error = Device->DeviceSetDtrRts(s,true,true);
+			if (error != ERR_NONE) return error;
+			my_sleep(1000);
 		}
 
-		for (count = 0; count < 55; count ++) {
-			if (Device->WriteDevice(s,&init_char,1)!=1) return ERR_DEVICEWRITEERROR;
-		}
+		error = Device->DeviceSetSpeed(s,19200);
+		if (error != ERR_NONE) return error;
+
+		error = FBUS2_ATSwitch(s);
+		if (error != ERR_NONE) return error;
+
+		error = Device->DeviceSetSpeed(s,115200);
+		if (error != ERR_NONE) return error;
+
+		error = FBUS2_InitSequence(s);
+		if (error != ERR_NONE) return error;
+
 		break;
 #endif
 	case GCT_FBUS2:
-	case GCT_FBUS2NODTR:
-		if (s->ConnectionType != GCT_FBUS2NODTR) {
-			error=Device->DeviceSetSpeed(s,115200);
-			if (error!=ERR_NONE) return error;
+		error = Device->DeviceSetSpeed(s,115200);
+		if (error != ERR_NONE) return error;
 
-			error=Device->DeviceSetDtrRts(s,true,false); /*DTR high,RTS low*/
-			if (error!=ERR_NONE) return error;
-		}
+		/* Set DTR as power supply if needed, RTS is always low */
+		error = Device->DeviceSetDtrRts(s, !(s->NoPowerCable), false);
+		if (error != ERR_NONE) return error;
+
+		error = FBUS2_InitSequence(s);
+		if (error != ERR_NONE) return error;
 
-		for (count = 0; count < 55; count ++) {
-			if (Device->WriteDevice(s,&init_char,1)!=1) return ERR_DEVICEWRITEERROR;
-			my_sleep(10);
-		}
 		break;
 #ifdef GSM_ENABLE_FBUS2IRDA
 	case GCT_FBUS2IRDA:
-		error=Device->DeviceSetSpeed(s,9600);
-		if (error!=ERR_NONE) return error;
+		error = Device->DeviceSetSpeed(s,9600);
+		if (error != ERR_NONE) return error;
 
-		for (count = 0; count < 55; count ++) {
-			if (Device->WriteDevice(s,&init_char,1)!=1) return ERR_DEVICEWRITEERROR;
-			my_sleep(10);
-		}
+		error = FBUS2_InitSequence(s);
+		if (error != ERR_NONE) return error;
 
-		if (Device->WriteDevice(s,&end_init_char,1)!=1) return ERR_DEVICEWRITEERROR;
-		my_sleep(20);
-
-		error=Device->DeviceSetSpeed(s,115200);
-		if (error!=ERR_NONE) return error;
+		error = Device->DeviceSetSpeed(s,115200);
+		if (error != ERR_NONE) return error;
 
 		break;
 #endif
@@ -454,6 +454,9 @@ static GSM_Error FBUS2_Initialise(GSM_StateMachine *s)
 		break;
 	}
 
+	/* Read any possible junk on the line */
+	s->Device.Functions->ReadDevice(s, buff, 255);
+
 	return ERR_NONE;
 }
 
@@ -462,7 +465,7 @@ static GSM_Error FBUS2_Terminate(GSM_StateMachine *s)
 	free(s->Protocol.Data.FBUS2.Msg.Buffer);
 	free(s->Protocol.Data.FBUS2.MultiMsg.Buffer);
 	s->Protocol.Data.FBUS2.Msg.Buffer 	= NULL;
-        s->Protocol.Data.FBUS2.MultiMsg.Buffer 	= NULL;
+	s->Protocol.Data.FBUS2.MultiMsg.Buffer 	= NULL;
 
 	my_sleep(200);
 	return ERR_NONE;
