@@ -13,9 +13,16 @@
 
 #ifdef GSM_ENABLE_BACKUP
 
+/**
+ * Helper define to check error code from fwrite.
+ */
+#define chk_fwrite(data, size, count, file) \
+	if (fwrite(data, size, count, file) != count) goto fail;
+
 GSM_Error SaveVCalendar(char *FileName, GSM_Backup *backup)
 {
-	int 		i, Length = 0;
+	int 		i;
+	size_t Length = 0;
 	unsigned char 	Buffer[1000];
 	FILE 		*file;
 
@@ -24,32 +31,35 @@ GSM_Error SaveVCalendar(char *FileName, GSM_Backup *backup)
 
 	Length=sprintf(Buffer, "BEGIN:VCALENDAR%c%c",13,10);
 	Length+=sprintf(Buffer+Length, "VERSION:1.0%c%c",13,10);
-	fwrite(Buffer,1,Length,file);
+	chk_fwrite(Buffer,1,Length,file);
 
 	i=0;
 	while (backup->Calendar[i]!=NULL) {
 		sprintf(Buffer, "%c%c",13,10);
-		fwrite(Buffer,1,2,file);
+		chk_fwrite(Buffer,1,2,file);
 		Length = 0;
 		GSM_EncodeVCALENDAR(Buffer,&Length,backup->Calendar[i],false,Nokia_VCalendar);
-		fwrite(Buffer,1,Length,file);
+		chk_fwrite(Buffer,1,Length,file);
 		i++;
 	}
 	i=0;
 	while (backup->ToDo[i]!=NULL) {
 		sprintf(Buffer, "%c%c",13,10);
-		fwrite(Buffer,1,2,file);
+		chk_fwrite(Buffer,1,2,file);
 		Length = 0;
 		GSM_EncodeVTODO(Buffer,&Length,backup->ToDo[i],false,Nokia_VToDo);
-		fwrite(Buffer,1,Length,file);
+		chk_fwrite(Buffer,1,Length,file);
 		i++;
 	}
 
 	Length=sprintf(Buffer, "%c%cEND:VCALENDAR%c%c",13,10,13,10);
-	fwrite(Buffer,1,Length,file);
+	chk_fwrite(Buffer,1,Length,file);
 
 	fclose(file);
 	return ERR_NONE;
+fail:
+	fclose(file);
+	return ERR_WRITING_FILE;
 }
 
 GSM_Error LoadVCalendar(char *FileName, GSM_Backup *backup)
