@@ -29,7 +29,6 @@ void GSM_SetCalendarRecurranceRepeat(unsigned char *rec, unsigned char *endday,
 {
 	unsigned int i;
 	int start=-1,frequency=-1,dow=-1,day=-1,month=-1,end=-1,Recurrance = 0, Repeat=0, j;
-	char 		Buf[20];
 	GSM_DateTime	DT;
 	time_t		t_time1,t_time2;
 
@@ -53,16 +52,9 @@ void GSM_SetCalendarRecurranceRepeat(unsigned char *rec, unsigned char *endday,
 		}
 	}
 
-	sprintf(Buf,"%s",DayOfWeek(entry->Entries[start].Date.Year,
+	i = GetDayOfWeek(entry->Entries[start].Date.Year,
 			entry->Entries[start].Date.Month,
-			entry->Entries[start].Date.Day));
-	if (!strcmp(Buf,"Mon")) i = 1;
-	if (!strcmp(Buf,"Tue")) i = 2;
-	if (!strcmp(Buf,"Wed")) i = 3;
-	if (!strcmp(Buf,"Thu")) i = 4;
-	if (!strcmp(Buf,"Fri")) i = 5;
-	if (!strcmp(Buf,"Sat")) i = 6;
-	if (!strcmp(Buf,"Sun")) i = 7;
+			entry->Entries[start].Date.Day);
 
 	if (frequency != -1 && dow != -1 && day == -1 && month == -1) {
 		if (entry->Entries[frequency].Number == 1 &&
@@ -142,7 +134,6 @@ void GSM_SetCalendarRecurranceRepeat(unsigned char *rec, unsigned char *endday,
 void GSM_GetCalendarRecurranceRepeat(unsigned char *rec, unsigned char *endday, GSM_CalendarEntry *entry)
 {
 	int 	Recurrance,num=-1,i;
-	char 	Buf[20];
 
 	Recurrance = rec[0]*256 + rec[1];
 	if (Recurrance == 0) return;
@@ -159,9 +150,6 @@ void GSM_GetCalendarRecurranceRepeat(unsigned char *rec, unsigned char *endday,
 		}
 	}
 	if (num == -1) return;
-	sprintf(Buf,"%s",DayOfWeek(entry->Entries[num].Date.Year,
-			entry->Entries[num].Date.Month,
-			entry->Entries[num].Date.Day));
 
 	if (Recurrance == 24    || Recurrance == 24*7 ||
 	    Recurrance == 24*30 || Recurrance == 24*365) {
@@ -176,21 +164,9 @@ void GSM_GetCalendarRecurranceRepeat(unsigned char *rec, unsigned char *endday,
 	}
 	if (Recurrance == 24*7 || Recurrance == 24*14) {
 		entry->Entries[entry->EntriesNum].EntryType	 = CAL_REPEAT_DAYOFWEEK;
-		if (!strcmp(Buf,"Mon")) {
-			entry->Entries[entry->EntriesNum].Number = 1;
-		} else if (!strcmp(Buf,"Tue")) {
-			entry->Entries[entry->EntriesNum].Number = 2;
-		} else if (!strcmp(Buf,"Wed")) {
-			entry->Entries[entry->EntriesNum].Number = 3;
-		} else if (!strcmp(Buf,"Thu")) {
-			entry->Entries[entry->EntriesNum].Number = 4;
-		} else if (!strcmp(Buf,"Fri")) {
-			entry->Entries[entry->EntriesNum].Number = 5;
-		} else if (!strcmp(Buf,"Sat")) {
-			entry->Entries[entry->EntriesNum].Number = 6;
-		} else if (!strcmp(Buf,"Sun")) {
-			entry->Entries[entry->EntriesNum].Number = 7;
-		}
+		entry->Entries[entry->EntriesNum].Number = GetDayOfWeek(entry->Entries[num].Date.Year,
+			entry->Entries[num].Date.Month,
+			entry->Entries[num].Date.Day);
 		entry->EntriesNum++;
 	}
 	if (Recurrance == 24*30) {
@@ -787,6 +763,7 @@ void GSM_ToDo_AdjustDate(GSM_ToDoEntry *note, GSM_DeltaTime *delta)
 			case TODO_ALARM_DATETIME :
 			case TODO_SILENT_ALARM_DATETIME:
 			case TODO_LAST_MODIFIED:
+			case TODO_START_DATETIME:
 				note->Entries[i].Date = GSM_AddTime(note->Entries[i].Date, *delta);
 				break;
 			case TODO_TEXT:
@@ -1051,6 +1028,9 @@ GSM_Error GSM_EncodeVTODO(char *Buffer, size_t *Length, GSM_ToDoEntry *note, boo
 					SaveVCALDateTime(Buffer, Length, &note->Entries[i].Date, "DALARM");
 				}
 				break;
+			case TODO_START_DATETIME:
+				SaveVCALDateTime(Buffer, Length, &note->Entries[i].Date, "DTSTART");
+				break;
 			case TODO_LAST_MODIFIED:
 				SaveVCALDateTime(Buffer, Length, &note->Entries[i].Date, "LAST-MODIFIED");
 				break;
@@ -1609,6 +1589,7 @@ GSM_Error GSM_DecodeVCALENDAR_VTODO(unsigned char *Buffer, int *Pos, GSM_Calenda
 			}
 			if (strstr(Line,"BEGIN:VTODO")) {
 				ToDo->Priority 	= GSM_Priority_None;
+				ToDo->Type = GSM_CAL_MEMO;
 				dstflag = 0;
 				Text=-1; Time=-1; Alarm=-1; EndTime=-1; Location=-1;
 				Level 		= 2;
@@ -1624,7 +1605,7 @@ GSM_Error GSM_DecodeVCALENDAR_VTODO(unsigned char *Buffer, int *Pos, GSM_Calenda
 					if (CalVer == Mozilla_iCalendar) {
 						/* @todo: We don't have parser for this right now */
 						error = ERR_NONE;
-					} else { 
+					} else {
 						error = GSM_DecodeVCAL_RRULE(rrule, Calendar, Time);
 					}
 					free(rrule);
@@ -1845,6 +1826,11 @@ GSM_Error GSM_DecodeVCALENDAR_VTODO(unsigned char *Buffer, int *Pos, GSM_Calenda
 					ToDo->EntriesNum++;
 				}
 			}
+			if (ReadVCALDate(Line, "DTSTART", &Date, &is_date_only)) {
+				ToDo->Entries[ToDo->EntriesNum].Date = Date;
+				ToDo->Entries[ToDo->EntriesNum].EntryType = TODO_START_DATETIME;
+				ToDo->EntriesNum++;
+			}
 			if (ReadVCALDate(Line, "DALARM", &Date, &is_date_only)) {
 				ToDo->Entries[ToDo->EntriesNum].Date = Date;
 				ToDo->Entries[ToDo->EntriesNum].EntryType = TODO_SILENT_ALARM_DATETIME;
