@@ -102,7 +102,7 @@ void GSM_PhonebookFindDefaultNameNumberGroup(GSM_MemoryEntry *entry, int *Name,
 	}
 }
 
-void GSM_EncodeVCARD(char *Buffer, int *Length, GSM_MemoryEntry *pbk, bool header, GSM_VCardVersion Version)
+void GSM_EncodeVCARD(char *Buffer, size_t *Length, GSM_MemoryEntry *pbk, bool header, GSM_VCardVersion Version)
 {
 	int Name, Number, Group, i;
 	int firstname = -1, lastname = -1;
@@ -209,6 +209,7 @@ void GSM_EncodeVCARD(char *Buffer, int *Length, GSM_MemoryEntry *pbk, bool heade
 					}
 					*Length+=sprintf(Buffer+(*Length),"TEL");
 					if (Version != SonyEricsson_VCard21 && Number == i) (*Length)+=sprintf(Buffer+(*Length),";PREF");
+					*Length+=sprintf(Buffer+(*Length),";OTHER");
 					break;
 				case PBK_Number_Pager:
 					if (UnicodeLength(pbk->Entries[i].Text) == 0) {
@@ -499,9 +500,12 @@ void GSM_TweakInternationalNumber(unsigned char *Number, const GSM_NumberType nu
 }
 
 
+/**
+ * \bug We should avoid using static buffers here.
+ */
 GSM_Error GSM_DecodeVCARD(unsigned char *Buffer, int *Pos, GSM_MemoryEntry *Pbk, GSM_VCardVersion Version UNUSED)
 {
-	unsigned char   Line[2000],Buff[2000];
+	unsigned char   Line[20000],Buff[20000];
 	int	     Level = 0;
 	unsigned char   *s;
 	int		pos;
@@ -546,7 +550,8 @@ GSM_Error GSM_DecodeVCARD(unsigned char *Buffer, int *Pos, GSM_MemoryEntry *Pbk,
 				}
 			}
 			if (ReadVCALText(Line, "TEL",		   Buff, false) ||
-			    ReadVCALText(Line, "TEL;VOICE",	     Buff, false)) {
+			    ReadVCALText(Line, "TEL;VOICE",	     Buff, false) ||
+			    ReadVCALText(Line, "TEL;TYPE=VOICE",	     Buff, false)) {
 				if (Buff[1] == '+') {
 					GSM_TweakInternationalNumber(Buff, NUMBER_INTERNATIONAL_NUMBERING_PLAN_ISDN);
 				}
@@ -559,6 +564,8 @@ GSM_Error GSM_DecodeVCARD(unsigned char *Buffer, int *Pos, GSM_MemoryEntry *Pbk,
 			if (ReadVCALText(Line, "TEL;CELL",	      Buff, false) ||
 			    ReadVCALText(Line, "TEL;CELL;VOICE",	Buff, false) ||
 			    ReadVCALText(Line, "TEL;TYPE=CELL",	 Buff, false) ||
+			    ReadVCALText(Line, "TEL;TYPE=CELL,VOICE",   Buff, false) ||
+			    ReadVCALText(Line, "TEL;TYPE=CELL;TYPE=VOICE",   Buff, false) ||
 			    ReadVCALText(Line, "TEL;TYPE=CELL;VOICE",   Buff, false)) {
 				if (Buff[1] == '+') {
 					GSM_TweakInternationalNumber(Buff, NUMBER_INTERNATIONAL_NUMBERING_PLAN_ISDN);
@@ -572,7 +579,9 @@ GSM_Error GSM_DecodeVCARD(unsigned char *Buffer, int *Pos, GSM_MemoryEntry *Pbk,
 			if (ReadVCALText(Line, "TEL;WORK",	      Buff, false) ||
 			    ReadVCALText(Line, "TEL;TYPE=WORK",	 Buff, false) ||
 			    ReadVCALText(Line, "TEL;WORK;VOICE",	Buff, false) ||
-			    ReadVCALText(Line, "TEL;TYPE=WORK;VOICE",   Buff, false)) {
+			    ReadVCALText(Line, "TEL;TYPE=WORK;VOICE",   Buff, false) ||
+			    ReadVCALText(Line, "TEL;TYPE=WORK;TYPE=VOICE",   Buff, false) ||
+			    ReadVCALText(Line, "TEL;TYPE=WORK,VOICE",   Buff, false)) {
 				if (Buff[1] == '+') {
 					GSM_TweakInternationalNumber(Buff, NUMBER_INTERNATIONAL_NUMBERING_PLAN_ISDN);
 				}
@@ -582,10 +591,28 @@ GSM_Error GSM_DecodeVCARD(unsigned char *Buffer, int *Pos, GSM_MemoryEntry *Pbk,
 				Pbk->Entries[Pbk->EntriesNum].VoiceTag = 0;
 				Pbk->EntriesNum++;
 			}
+			if (ReadVCALText(Line, "TEL;OTHER",	      Buff, false) ||
+			    ReadVCALText(Line, "TEL;TYPE=OTHER",	 Buff, false) ||
+			    ReadVCALText(Line, "TEL;OTHER;VOICE",	Buff, false) ||
+			    ReadVCALText(Line, "TEL;TYPE=OTHER;VOICE",   Buff, false) ||
+			    ReadVCALText(Line, "TEL;TYPE=OTHER;TYPE=VOICE",   Buff, false) ||
+			    ReadVCALText(Line, "TEL;TYPE=OTHER,VOICE",   Buff, false)) {
+				if (Buff[1] == '+') {
+					GSM_TweakInternationalNumber(Buff, NUMBER_INTERNATIONAL_NUMBERING_PLAN_ISDN);
+				}
+				CopyUnicodeString(Pbk->Entries[Pbk->EntriesNum].Text,Buff);
+				Pbk->Entries[Pbk->EntriesNum].EntryType = PBK_Number_Other;
+				Pbk->Entries[Pbk->EntriesNum].SMSList[0] = 0;
+				Pbk->Entries[Pbk->EntriesNum].VoiceTag = 0;
+				Pbk->EntriesNum++;
+			}
+			/* FAX + VOICE looks like nonsense */
 			if (ReadVCALText(Line, "TEL;FAX",	       Buff, false) ||
 			    ReadVCALText(Line, "TEL;TYPE=FAX",	  Buff, false) ||
 			    ReadVCALText(Line, "TEL;FAX;VOICE",	 Buff, false) ||
-			    ReadVCALText(Line, "TEL;TYPE=FAX;VOICE",    Buff, false)) {
+			    ReadVCALText(Line, "TEL;TYPE=FAX;VOICE",    Buff, false) ||
+			    ReadVCALText(Line, "TEL;TYPE=FAX;TYPE=VOICE",    Buff, false) ||
+			    ReadVCALText(Line, "TEL;TYPE=FAX,VOICE",    Buff, false)) {
 				if (Buff[1] == '+') {
 					GSM_TweakInternationalNumber(Buff, NUMBER_INTERNATIONAL_NUMBERING_PLAN_ISDN);
 				}
@@ -598,6 +625,8 @@ GSM_Error GSM_DecodeVCARD(unsigned char *Buffer, int *Pos, GSM_MemoryEntry *Pbk,
 			if (ReadVCALText(Line, "TEL;HOME",	      Buff, false) ||
 			    ReadVCALText(Line, "TEL;TYPE=HOME",	 Buff, false) ||
 			    ReadVCALText(Line, "TEL;HOME;VOICE",	Buff, false) ||
+			    ReadVCALText(Line, "TEL;TYPE=HOME,VOICE",   Buff, false) ||
+			    ReadVCALText(Line, "TEL;TYPE=HOME;TYPE=VOICE",   Buff, false) ||
 			    ReadVCALText(Line, "TEL;TYPE=HOME;VOICE",   Buff, false)) {
 				if (Buff[1] == '+') {
 					GSM_TweakInternationalNumber(Buff, NUMBER_INTERNATIONAL_NUMBERING_PLAN_ISDN);
@@ -711,6 +740,7 @@ GSM_Error GSM_DecodeVCARD(unsigned char *Buffer, int *Pos, GSM_MemoryEntry *Pbk,
 				}
 			}
 			if (ReadVCALText(Line, "EMAIL", Buff, false) ||
+			    ReadVCALText(Line, "EMAIL;TYPE=OTHER", Buff, false) ||
 			    ReadVCALText(Line, "EMAIL;INTERNET", Buff, false)) {
 				CopyUnicodeString(Pbk->Entries[Pbk->EntriesNum].Text,Buff);
 				Pbk->Entries[Pbk->EntriesNum].EntryType = PBK_Text_Email;
