@@ -258,6 +258,11 @@ GSM_Error GSM_DecodeSMSFrameText(GSM_SMSMessage *SMS, unsigned char *buffer, GSM
 				w=(i-off)%i;
 			} while (w<0);
 			SMS->Length=buffer[Layout.TPUDL] - (off*8 + w) / 7;
+			if (SMS->Length < 0) {
+				dbgprintf("No SMS text!\n");
+				SMS->Length = 0;
+				break;
+			}
 			tmp=GSM_UnpackEightBitsToSeven(w, buffer[Layout.TPUDL]-off, SMS->Length, buffer+(Layout.Text+off), output);
 			dbgprintf("7 bit SMS, length %i\n",SMS->Length);
 			DecodeDefault (SMS->Text, output, SMS->Length, true, NULL);
@@ -659,7 +664,6 @@ void GSM_SetDefaultReceivedSMSData(GSM_SMSMessage *SMS)
 	SMS->Class			= 0;
 	SMS->Text[0] 			= 0;
 	SMS->Text[1] 			= 0;
-	SMS->PDU			= SMS_Submit;
 	SMS->RejectDuplicates		= false;
 	SMS->MessageReference		= 0;
 	SMS->ReplaceMessage		= 0;
@@ -672,9 +676,11 @@ void GSM_SetDefaultSMSData(GSM_SMSMessage *SMS)
 
 	SMS->SMSC.Validity.Format	= SMS_Validity_RelativeFormat;
 	SMS->SMSC.Validity.Relative	= SMS_VALID_Max_Time;
+	SMS->SMSC.Location		= 1;
 
 	/* This part is required to save SMS */
 	SMS->State			= SMS_UnSent;
+	SMS->PDU			= SMS_Submit;
 	SMS->Location			= 0;
 	SMS->Memory			= 0;
 	SMS->Folder			= 0x02;	/*Outbox*/
