@@ -12,10 +12,10 @@
 
 #define GAMMU_CALLER_GROUPS	20
 
-GSM_Bitmap		caller[GAMMU_CALLER_GROUPS];
-GSM_AllRingtonesInfo 	Info = {0, NULL};
-bool			callerinit[GAMMU_CALLER_GROUPS] = {false, false, false, false, false};
-bool			ringinit = false;
+static GSM_Bitmap		caller[GAMMU_CALLER_GROUPS];
+static GSM_AllRingtonesInfo 	Info = {0, NULL};
+static bool			callerinit[GAMMU_CALLER_GROUPS] = {false, false, false, false, false};
+static bool			ringinit = false;
 
 void PrintMemorySubEntry(GSM_SubMemoryEntry *entry)
 {
@@ -209,14 +209,14 @@ void GetMemory(int argc, char *argv[])
 	GSM_Init(true);
 
 	if (strcmp(GSM_GetModelInfo(gsm)->model, "3310") == 0) {
-		GSM_GetFirmware(gsm, NULL, NULL, &version);
-		if (version <= 4.06) {
+		error = GSM_GetFirmware(gsm, NULL, NULL, &version);
+		if (error == ERR_NONE && version <= 4.06) {
 			printf_warn("%s\n", _("You will have null names in entries. Upgrade firmware in phone to higher than 4.06"));
 		}
 	}
 	if (strcmp(GSM_GetModelInfo(gsm)->model, "3210") == 0) {
-		GSM_GetFirmware(gsm, NULL, NULL, &version);
-		if (version <= 6.00) {
+		error = GSM_GetFirmware(gsm, NULL, NULL, &version);
+		if (error == ERR_NONE && version <= 6.00) {
 			printf_warn("%s\n", _("You will have null names in entries. Upgrade firmware in phone to higher than 6.00"));
 		}
 	}
