@@ -28,7 +28,7 @@ GSM_MultiSMSMessage		IncomingSMSData;
 /**
  * Prints location information about message.
  */
-void PrintSMSLocation(const GSM_SMSMessage *sms, const GSM_SMSFolders *folders) 
+void PrintSMSLocation(const GSM_SMSMessage *sms, const GSM_SMSFolders *folders)
 {
 	printf(_("Location %i, folder \"%s\""),
 			sms->Location,
@@ -36,16 +36,16 @@ void PrintSMSLocation(const GSM_SMSMessage *sms, const GSM_SMSFolders *folders)
 			);
 
 	switch (sms->Memory) {
-		case MEM_SM: 
+		case MEM_SM:
 			printf(", %s", _("SIM memory"));
 			break;
-		case MEM_ME: 
+		case MEM_ME:
 			printf(", %s", _("phone memory"));
 			break;
-		case MEM_MT: 
-			printf(", %s", _("phone or SIM memory")); 
+		case MEM_MT:
+			printf(", %s", _("phone or SIM memory"));
 			break;
-		default: 
+		default:
 			break;
 	}
 
@@ -765,7 +765,9 @@ void GetAllSMS(int argc, char *argv[])
 					        if (Backup.PhonePhonebook[used] == NULL) Print_Error(ERR_MOREMEMORY);
 						Backup.PhonePhonebook[used+1] = NULL;
 					} else {
-						printf(_("\n   Only part of data saved - increase %s") , "GSM_BACKUP_MAX_PHONEPHONEBOOK");
+						printf("\n   ");
+						printf(_("Only part of data saved, please increase %s.") , "GSM_BACKUP_MAX_PHONEPHONEBOOK");
+						printf("\n");
 						break;
 					}
 					*Backup.PhonePhonebook[used]=Pbk;
@@ -854,7 +856,9 @@ void GetEachSMS(int argc, char *argv[])
 					        if (Backup.PhonePhonebook[used] == NULL) Print_Error(ERR_MOREMEMORY);
 						Backup.PhonePhonebook[used+1] = NULL;
 					} else {
-						printf(_("\n   Only part of data saved - increase %s") , "GSM_BACKUP_MAX_PHONEPHONEBOOK");
+						printf("\n   ");
+						printf(_("Only part of data saved, please increase %s.") , "GSM_BACKUP_MAX_PHONEPHONEBOOK");
+						printf("\n");
 						break;
 					}
 					*Backup.PhonePhonebook[used]=Pbk;
@@ -1128,7 +1132,8 @@ void GetEachMMS(int argc, char *argv[])
 			error = GSM_GetFilePart(gsm,&File,&Handle,&Size);
 			if (error == ERR_EMPTY) break;
 			Print_Error(error);
-			fprintf(stderr, _("%c  Reading: %i percent"),13, (int)(File.Used*100/Size));
+			fprintf(stderr, "\r   ");
+			fprintf(stderr, _("Reading: %i percent"), (int)(File.Used*100/Size));
 		}
 		fprintf(stderr, "%c",13);
 
@@ -1271,6 +1276,8 @@ void SendSaveDisplaySMS(int argc, char *argv[])
 	GSM_ClearMultiPartSMSInfo(&SMSInfo);
 	SMSInfo.ReplaceMessage		= 0;
 	SMSInfo.EntriesNum		= 1;
+	Validity.Format = 0;
+	Validity.Relative = 0;
 
 	if (SaveSMS) {
 		EncodeUnicode(Sender,"Gammu",5);
@@ -1280,7 +1287,6 @@ void SendSaveDisplaySMS(int argc, char *argv[])
 	} else {
 		EncodeUnicode(Sender,argv[3],strlen(argv[3]));
 		startarg 	= 1;
-		Validity.Format = 0;
 	}
 
 	if (SendSMSDSMS) {
