@@ -7,7 +7,6 @@
 #include <signal.h>
 #include <stdlib.h>
 #include <ctype.h>
-#include <unistd.h>
 #include <gammu.h>
 
 #include "common.h"
@@ -66,13 +65,13 @@ GSM_Error GSM_PlayRingtone(GSM_Ringtone ringtone)
 	for (i=0;i<ringtone.NoteTone.NrCommands;i++) {
 		if (gshutdown) break;
 		if (ringtone.NoteTone.Commands[i].Type != RING_NOTETONE) continue;
-		error=PHONE_RTTLPlayOneNote(s,ringtone.NoteTone.Commands[i].Note,first);
+		error=PHONE_RTTLPlayOneNote(gsm,ringtone.NoteTone.Commands[i].Note,first);
 		if (error!=ERR_NONE) return error;
 		first = false;
 	}
 
 	/* Disables buzzer */
-	return GSM_PlayTone(s,255*255,0,false);
+	return GSM_PlayTone(gsm,255*255,0,false);
 }
 
 void PlayRingtone(int argc UNUSED, char *argv[])
@@ -97,26 +96,26 @@ void PlayRingtone(int argc UNUSED, char *argv[])
 
 void Identify(int argc, char *argv[])
 {
-	char buffer[100];
-	char date[100];
+	char buffer[GSM_MAX_INFO_LENGTH];
+	char date[GSM_MAX_VERSION_DATE_LENGTH];
 	double num;
 	GSM_Error error;
 
 	GSM_Init(true);
 
-	error=GSM_GetManufacturer(s, buffer);
+	error=GSM_GetManufacturer(gsm, buffer);
 	Print_Error(error);
 	printf(LISTFORMAT "%s\n", _("Manufacturer"), buffer);
-	error=GSM_GetModel(s, buffer);
+	error=GSM_GetModel(gsm, buffer);
 	Print_Error(error);
 	printf(LISTFORMAT "%s (%s)\n", _("Model"),
-			GSM_GetModelInfo(s)->model,
+			GSM_GetModelInfo(gsm)->model,
 			buffer);
 
-	error=GSM_GetFirmware(s, buffer, date, &num);
+	error=GSM_GetFirmware(gsm, buffer, date, &num);
 	Print_Error(error);
 	printf(LISTFORMAT "%s", _("Firmware"), buffer);
-	error=GSM_GetPPM(s, buffer);
+	error=GSM_GetPPM(gsm, buffer);
 	if (error != ERR_NOTSUPPORTED) {
 		if (error != ERR_NOTIMPLEMENTED) Print_Error(error);
 		if (error == ERR_NONE) printf(" %s", buffer);
@@ -124,37 +123,37 @@ void Identify(int argc, char *argv[])
 	if (date[0] != 0) printf(" (%s)", date);
 	printf("\n");
 
-	error=GSM_GetHardware(s, buffer);
+	error=GSM_GetHardware(gsm, buffer);
 	if (error != ERR_NOTSUPPORTED) {
 		if (error != ERR_NOTIMPLEMENTED) Print_Error(error);
 		if (error == ERR_NONE) printf(LISTFORMAT "%s\n", _("Hardware"),buffer);
 	}
 
-	error=GSM_GetIMEI(s, buffer);
+	error=GSM_GetIMEI(gsm, buffer);
 	if (error != ERR_NOTSUPPORTED) {
 		if (error != ERR_NOTIMPLEMENTED) Print_Error(error);
 		if (error == ERR_NONE) printf(LISTFORMAT "%s\n", _("IMEI"), buffer);
 
-		error=GSM_GetOriginalIMEI(s, buffer);
+		error=GSM_GetOriginalIMEI(gsm, buffer);
 		if (error != ERR_NOTSUPPORTED && error != ERR_SECURITYERROR) {
 			if (error != ERR_NOTIMPLEMENTED) Print_Error(error);
 			if (error == ERR_NONE) printf(LISTFORMAT "%s\n", _("Original IMEI"), buffer);
 		}
 	}
 
-	error=GSM_GetManufactureMonth(s, buffer);
+	error=GSM_GetManufactureMonth(gsm, buffer);
 	if (error != ERR_NOTSUPPORTED && error != ERR_SECURITYERROR) {
 		if (error != ERR_NOTIMPLEMENTED) Print_Error(error);
 		if (error == ERR_NONE) printf(LISTFORMAT "%s\n", _("Manufactured"),buffer);
 	}
 
-	error=GSM_GetProductCode(s, buffer);
+	error=GSM_GetProductCode(gsm, buffer);
 	if (error != ERR_NOTSUPPORTED) {
 		if (error != ERR_NOTIMPLEMENTED) Print_Error(error);
 		if (error == ERR_NONE) printf(LISTFORMAT "%s\n", _("Product code"),buffer);
 	}
 
-	error=GSM_GetSIMIMSI(s, buffer);
+	error=GSM_GetSIMIMSI(gsm, buffer);
 	switch (error) {
 		case ERR_SECURITYERROR:
 		case ERR_NOTSUPPORTED:
@@ -183,13 +182,13 @@ void NetworkInfo(int argc UNUSED, char *argv[] UNUSED)
 
 	GSM_Init(true);
 
-	if (GSM_GetNetworkInfo(s,&NetInfo)==ERR_NONE) {
+	if (GSM_GetNetworkInfo(gsm,&NetInfo)==ERR_NONE) {
 		PrintNetworkInfo(NetInfo);
 	}
 	GSM_Terminate();
 }
 
-void IncomingCall(GSM_StateMachine *s UNUSED, GSM_Call call)
+void IncomingCall(GSM_StateMachine *sm UNUSED, GSM_Call call)
 {
 	printf(LISTFORMAT, _("Call info"));
 	if (call.CallIDAvailable) printf(_("ID %i, "),call.CallID);
@@ -219,7 +218,7 @@ void IncomingCall(GSM_StateMachine *s UNUSED, GSM_Call call)
 #define CHECKMEMORYSTATUS(x, m, name) \
 { \
 	x.MemoryType=m;							\
-	if ( (error = GSM_GetMemoryStatus(s, &x)) == ERR_NONE)			\
+	if ( (error = GSM_GetMemoryStatus(gsm, &x)) == ERR_NONE)			\
 		PRINTUSED(name, x.MemoryUsed, x.MemoryFree);  \
 }
 
@@ -252,18 +251,18 @@ void Monitor(int argc, char *argv[])
 
 	GSM_Init(true);
 
-	GSM_SetIncomingSMSCallback(s, IncomingSMS);
-	GSM_SetIncomingCBCallback(s, IncomingCB);
-	GSM_SetIncomingCallCallback(s, IncomingCall);
-	GSM_SetIncomingUSSDCallback(s, IncomingUSSD);
+	GSM_SetIncomingSMSCallback(gsm, IncomingSMS);
+	GSM_SetIncomingCBCallback(gsm, IncomingCB);
+	GSM_SetIncomingCallCallback(gsm, IncomingCall);
+	GSM_SetIncomingUSSDCallback(gsm, IncomingUSSD);
 
-	error=GSM_SetIncomingSMS  		(s,true);
+	error=GSM_SetIncomingSMS  		(gsm,true);
 	printf("%-35s : %s\n", _("Enabling info about incoming SMS"), GSM_ErrorString(error));
-	error=GSM_SetIncomingCB   		(s,true);
+	error=GSM_SetIncomingCB   		(gsm,true);
 	printf("%-35s : %s\n", _("Enabling info about incoming CB"), GSM_ErrorString(error));
-	error=GSM_SetIncomingCall 		(s,true);
+	error=GSM_SetIncomingCall 		(gsm,true);
 	printf("%-35s : %s\n", _("Enabling info about calls"), GSM_ErrorString(error));
-	error=GSM_SetIncomingUSSD 		(s,true);
+	error=GSM_SetIncomingUSSD 		(gsm,true);
 	printf("%-35s : %s\n", _("Enabling info about USSD"), GSM_ErrorString(error));
 
 	while (!gshutdown && count != 0) {
@@ -280,15 +279,15 @@ void Monitor(int argc, char *argv[])
 		CHECK_EXIT;
 		CHECKMEMORYSTATUS(MemStatus,MEM_ME,"Phone phonebook");
 		CHECK_EXIT;
-		if ( (error = GSM_GetToDoStatus(s, &ToDoStatus)) == ERR_NONE) {
+		if ( (error = GSM_GetToDoStatus(gsm, &ToDoStatus)) == ERR_NONE) {
 			PRINTUSED(_("ToDos"), ToDoStatus.Used, ToDoStatus.Free);
 		}
 		CHECK_EXIT;
-		if ( (error = GSM_GetCalendarStatus(s, &CalendarStatus)) == ERR_NONE) {
+		if ( (error = GSM_GetCalendarStatus(gsm, &CalendarStatus)) == ERR_NONE) {
 			PRINTUSED(_("Calendar"), CalendarStatus.Used, CalendarStatus.Free);
 		}
 		CHECK_EXIT;
-		if ( (error = GSM_GetBatteryCharge(s,&BatteryCharge)) == ERR_NONE) {
+		if ( (error = GSM_GetBatteryCharge(gsm,&BatteryCharge)) == ERR_NONE) {
             		if (BatteryCharge.BatteryPercent != -1) {
 				printf(LISTFORMAT, _("Battery level"));
 				printf(_("%i percent"), BatteryCharge.BatteryPercent);
@@ -382,7 +381,7 @@ void Monitor(int argc, char *argv[])
             		}
         	}
 		CHECK_EXIT;
-		if ( (error = GSM_GetSignalQuality(s,&SignalQuality)) == ERR_NONE) {
+		if ( (error = GSM_GetSignalQuality(gsm,&SignalQuality)) == ERR_NONE) {
             		if (SignalQuality.SignalStrength != -1) {
 				printf(LISTFORMAT, _("Signal strength"));
 				printf(_("%i dBm"), SignalQuality.SignalStrength);
@@ -400,7 +399,7 @@ void Monitor(int argc, char *argv[])
 			}
         	}
 		CHECK_EXIT;
-		if ( (error = GSM_GetSMSStatus(s,&SMSStatus)) == ERR_NONE) {
+		if ( (error = GSM_GetSMSStatus(gsm,&SMSStatus)) == ERR_NONE) {
 			if (SMSStatus.SIMSize > 0) {
 				printf(LISTFORMAT, _("SIM SMS status"));
 				printf(_("%i used"), SMSStatus.SIMUsed);
@@ -426,7 +425,7 @@ void Monitor(int argc, char *argv[])
 			}
 		}
 		CHECK_EXIT;
-		if ( (error = GSM_GetNetworkInfo(s,&NetInfo)) == ERR_NONE) {
+		if ( (error = GSM_GetNetworkInfo(gsm,&NetInfo)) == ERR_NONE) {
 			PrintNetworkInfo(NetInfo);
 		}
 		if (wasincomingsms) DisplayIncomingSMS();
@@ -454,7 +453,7 @@ void GetRingtone(int argc, char *argv[])
 
 	ringtone.Format=0;
 
-	error=GSM_GetRingtone(s,&ringtone,PhoneRingtone);
+	error=GSM_GetRingtone(gsm,&ringtone,PhoneRingtone);
 	Print_Error(error);
 
 	switch (ringtone.Format) {
@@ -481,7 +480,7 @@ void GetRingtonesList(int argc UNUSED, char *argv[] UNUSED)
 
 	GSM_Init(true);
 
-	error=GSM_GetRingtonesInfo(s,&Info);
+	error=GSM_GetRingtonesInfo(gsm,&Info);
  	if (error != ERR_NONE && Info.Ringtone) free(Info.Ringtone);
 	Print_Error(error);
 
@@ -508,7 +507,7 @@ void DialVoice(int argc, char *argv[])
 
 	GSM_Init(true);
 
-	error=GSM_DialVoice(s, argv[2], ShowNumber);
+	error=GSM_DialVoice(gsm, argv[2], ShowNumber);
 	Print_Error(error);
 
 	GSM_Terminate();
@@ -516,7 +515,7 @@ void DialVoice(int argc, char *argv[])
 
 int TerminateID = -1;
 
-void IncomingCall0(GSM_StateMachine *s UNUSED, GSM_Call call)
+void IncomingCall0(GSM_StateMachine *sm UNUSED, GSM_Call call)
 {
 	if (call.CallIDAvailable) TerminateID = call.CallID;
 }
@@ -525,8 +524,6 @@ void MakeTerminatedCall(int argc, char *argv[])
 {
 	GSM_CallShowNumber 	ShowNumber = GSM_CALL_DefaultNumberPresence;
 	GSM_Error error;
-//	GSM_DateTime		DT;
-//	time_t			one,two;
 
 	if (argc > 4) {
 		if (strcasecmp(argv[4],"show") == 0) {		ShowNumber = GSM_CALL_ShowNumber;
@@ -540,27 +537,19 @@ void MakeTerminatedCall(int argc, char *argv[])
 	GSM_Init(true);
 
 	TerminateID = -1;
-	GSM_SetIncomingCallCallback(s, IncomingCall0);
+	GSM_SetIncomingCallCallback(gsm, IncomingCall0);
 
-	error=GSM_SetIncomingCall(s,true);
+	error=GSM_SetIncomingCall(gsm,true);
 	Print_Error(error);
 
-	error=GSM_DialVoice(s, argv[2], ShowNumber);
+	error=GSM_DialVoice(gsm, argv[2], ShowNumber);
 	Print_Error(error);
 
-//	GSM_GetCurrentDateTime (&DT);
-//	one = Fill_Time_T(DT);
-
-//	while (true) {
-		my_sleep(atoi(argv[3]));
-//		GSM_GetCurrentDateTime (&DT);
-//		two = Fill_Time_T(DT);
-//		if (two - one > atoi(argv[3])) break;
-		GSM_ReadDevice(s,true);
-//	}
+	my_sleep(atoi(argv[3]));
+	GSM_ReadDevice(gsm,true);
 
 	if (TerminateID != -1) {
-		error=GSM_CancelCall(s,TerminateID,false);
+		error=GSM_CancelCall(gsm,TerminateID,false);
 		Print_Error(error);
 	}
 
@@ -574,9 +563,9 @@ void CancelCall(int argc, char *argv[])
 	GSM_Init(true);
 
 	if (argc>2) {
-		error=GSM_CancelCall(s,atoi(argv[2]),false);
+		error=GSM_CancelCall(gsm,atoi(argv[2]),false);
 	} else {
-		error=GSM_CancelCall(s,0,true);
+		error=GSM_CancelCall(gsm,0,true);
 	}
 	Print_Error(error);
 
@@ -589,9 +578,9 @@ void AnswerCall(int argc, char *argv[])
 	GSM_Init(true);
 
 	if (argc>2) {
-		error=GSM_AnswerCall(s,atoi(argv[2]),false);
+		error=GSM_AnswerCall(gsm,atoi(argv[2]),false);
 	} else {
-		error=GSM_AnswerCall(s,0,true);
+		error=GSM_AnswerCall(gsm,0,true);
 	}
 	Print_Error(error);
 
@@ -603,7 +592,7 @@ void UnholdCall(int argc UNUSED, char *argv[])
 	GSM_Error error;
 	GSM_Init(true);
 
-	error=GSM_UnholdCall(s,atoi(argv[2]));
+	error=GSM_UnholdCall(gsm,atoi(argv[2]));
 	Print_Error(error);
 
 	GSM_Terminate();
@@ -614,7 +603,7 @@ void HoldCall(int argc UNUSED, char *argv[])
 	GSM_Error error;
 	GSM_Init(true);
 
-	error=GSM_HoldCall(s,atoi(argv[2]));
+	error=GSM_HoldCall(gsm,atoi(argv[2]));
 	Print_Error(error);
 
 	GSM_Terminate();
@@ -625,7 +614,7 @@ void ConferenceCall(int argc UNUSED, char *argv[])
 	GSM_Error error;
 	GSM_Init(true);
 
-	error=GSM_ConferenceCall(s,atoi(argv[2]));
+	error=GSM_ConferenceCall(gsm,atoi(argv[2]));
 	Print_Error(error);
 
 	GSM_Terminate();
@@ -636,7 +625,7 @@ void SplitCall(int argc UNUSED, char *argv[])
 	GSM_Error error;
 	GSM_Init(true);
 
-	error=GSM_SplitCall(s,atoi(argv[2]));
+	error=GSM_SplitCall(gsm,atoi(argv[2]));
 	Print_Error(error);
 
 	GSM_Terminate();
@@ -648,9 +637,9 @@ void SwitchCall(int argc, char *argv[])
 	GSM_Init(true);
 
 	if (argc > 2) {
-		error=GSM_SwitchCall(s,atoi(argv[2]),false);
+		error=GSM_SwitchCall(gsm,atoi(argv[2]),false);
 	} else {
-		error=GSM_SwitchCall(s,0,true);
+		error=GSM_SwitchCall(gsm,0,true);
 	}
 	Print_Error(error);
 
@@ -663,9 +652,9 @@ void TransferCall(int argc, char *argv[])
 	GSM_Init(true);
 
 	if (argc > 2) {
-		error=GSM_TransferCall(s,atoi(argv[2]),false);
+		error=GSM_TransferCall(gsm,atoi(argv[2]),false);
 	} else {
-		error=GSM_TransferCall(s,0,true);
+		error=GSM_TransferCall(gsm,0,true);
 	}
 	Print_Error(error);
 
@@ -686,7 +675,7 @@ void Reset(int argc UNUSED, char *argv[])
 
 	GSM_Init(true);
 
-	error=GSM_Reset(s, hard);
+	error=GSM_Reset(gsm, hard);
 	Print_Error(error);
 
 	GSM_Terminate();
@@ -704,7 +693,7 @@ void GetWAPBookmark(int argc, char *argv[])
 
 	for (i=start;i<=stop;i++) {
 		bookmark.Location=i;
-		error=GSM_GetWAPBookmark(s,&bookmark);
+		error=GSM_GetWAPBookmark(gsm,&bookmark);
 		Print_Error(error);
 		printf(LISTFORMAT "\"%s\"\n", _("Name"),DecodeUnicodeConsole(bookmark.Title));
 		printf(LISTFORMAT "\"%s\"\n", _("Address"),DecodeUnicodeConsole(bookmark.Address));
@@ -725,7 +714,7 @@ void DeleteWAPBookmark(int argc, char *argv[])
 
 	for (i=start;i<=stop;i++) {
 		bookmark.Location=i;
-		error=GSM_DeleteWAPBookmark(s, &bookmark);
+		error=GSM_DeleteWAPBookmark(gsm, &bookmark);
 		Print_Error(error);
 	}
 
@@ -744,7 +733,7 @@ void GetGPRSPoint(int argc, char *argv[])
 
 	for (i=start;i<=stop;i++) {
 		point.Location=i;
-		error=GSM_GetGPRSAccessPoint(s,&point);
+		error=GSM_GetGPRSAccessPoint(gsm,&point);
 		if (error != ERR_EMPTY) {
 			Print_Error(error);
 			printf("%i. \"%s\"",point.Location,DecodeUnicodeConsole(point.Name));
@@ -798,7 +787,7 @@ void GetBitmap(int argc, char *argv[])
 
 	GSM_Init(true);
 
-	error=GSM_GetBitmap(s,&MultiBitmap.Bitmap[0]);
+	error=GSM_GetBitmap(gsm,&MultiBitmap.Bitmap[0]);
 	Print_Error(error);
 
 	MultiBitmap.Number = 1;
@@ -812,7 +801,7 @@ void GetBitmap(int argc, char *argv[])
 		printf("\n");
 		if (MultiBitmap.Bitmap[0].DefaultRingtone) {
 			printf(LISTFORMAT "%s\n", _("Ringtone"), _("default"));
-		} else if (GSM_IsPhoneFeatureAvailable(GSM_GetModelInfo(s), F_6230iCALLER)) {
+		} else if (GSM_IsPhoneFeatureAvailable(GSM_GetModelInfo(gsm), F_6230iCALLER)) {
 			printf(LISTFORMAT "%i\n", _("Ringtone"),MultiBitmap.Bitmap[0].RingtoneID);
 		} else if (MultiBitmap.Bitmap[0].FileSystemRingtone) {
 			sprintf(buffer,"%i",MultiBitmap.Bitmap[0].RingtoneID);
@@ -821,17 +810,15 @@ void GetBitmap(int argc, char *argv[])
 			File.Buffer 	= NULL;
 			File.Used 	= 0;
 
-			error = ERR_NONE;
-//			while (error == ERR_NONE) {
-				error = GSM_GetFilePart(s,&File,&Handle,&Size);
-//			}
+			error = GSM_GetFilePart(gsm,&File,&Handle,&Size);
+
 		    	if (error != ERR_EMPTY && error != ERR_WRONGCRC) Print_Error(error);
 			error = ERR_NONE;
 
 			printf(LISTFORMAT "\"%s\" ", _("Ringtone"), DecodeUnicodeString(File.Name));
 			printf(_("(file with ID %i)\n"), MultiBitmap.Bitmap[0].RingtoneID);
 		} else {
-			error = GSM_GetRingtonesInfo(s,&Info);
+			error = GSM_GetRingtonesInfo(gsm,&Info);
 			if (error != ERR_NONE) Info.Number = 0;
 			error = ERR_NONE;
 
@@ -950,7 +937,7 @@ void SetBitmap(int argc, char *argv[])
 			init = false;
 			NewBitmap.Type 	   = GSM_CallerGroupLogo;
 			NewBitmap.Location = i;
-			error=GSM_GetBitmap(s,&NewBitmap);
+			error=GSM_GetBitmap(gsm,&NewBitmap);
 			Print_Error(error);
 			Bitmap.RingtoneID	  = NewBitmap.RingtoneID;
 			Bitmap.DefaultRingtone 	  = NewBitmap.DefaultRingtone;
@@ -983,7 +970,7 @@ void SetBitmap(int argc, char *argv[])
 			} else {
 				GSM_Init(true);
 				init = false;
-				error=GSM_GetNetworkInfo(s,&NetInfo);
+				error=GSM_GetNetworkInfo(gsm,&NetInfo);
 				Print_Error(error);
 				strcpy(Bitmap.NetworkCode,NetInfo.NetworkCode);
 			}
@@ -1011,7 +998,7 @@ void SetBitmap(int argc, char *argv[])
 			} else {
 				GSM_Init(true);
 				init = false;
-				error=GSM_GetNetworkInfo(s,&NetInfo);
+				error=GSM_GetNetworkInfo(gsm,&NetInfo);
 				Print_Error(error);
 				strcpy(MultiBitmap.Bitmap[0].NetworkCode,NetInfo.NetworkCode);
 			}
@@ -1024,7 +1011,7 @@ void SetBitmap(int argc, char *argv[])
 
 	if (init) GSM_Init(true);
 
-	error=GSM_SetBitmap(s,&Bitmap);
+	error=GSM_SetBitmap(gsm,&Bitmap);
 	Print_Error(error);
 
 #ifdef GSM_ENABLE_BEEP
@@ -1081,7 +1068,7 @@ void SetRingtone(int argc, char *argv[])
 	}
 
 	GSM_Init(true);
-	error=GSM_SetRingtone(s, &ringtone, &i);
+	error=GSM_SetRingtone(gsm, &ringtone, &i);
 	Print_Error(error);
 #ifdef GSM_ENABLE_BEEP
 	GSM_PhoneBeep();
@@ -1099,18 +1086,18 @@ void ClearMemory(GSM_MemoryType type, const char *question)
 
 	DoClear = false;
 	MemStatus.MemoryType = type;
-	error = GSM_GetMemoryStatus(s, &MemStatus);
+	error = GSM_GetMemoryStatus(gsm, &MemStatus);
 	if (error == ERR_NONE && MemStatus.MemoryUsed !=0) {
-		if (answer_yes(question)) DoClear = true;
+		if (answer_yes("%s", question)) DoClear = true;
 	}
 	if (DoClear) {
-		error = GSM_DeleteAllMemory(s, type);
+		error = GSM_DeleteAllMemory(gsm, type);
 		if (error == ERR_NOTSUPPORTED || error == ERR_NOTIMPLEMENTED) {
 			for (i = 0; i < MemStatus.MemoryUsed + MemStatus.MemoryFree; i++) {
 				Pbk.MemoryType 	= type;
 				Pbk.Location	= i + 1;
 				Pbk.EntriesNum	= 0;
-				error=GSM_DeleteMemory(s, &Pbk);
+				error=GSM_DeleteMemory(gsm, &Pbk);
 				Print_Error(error);
 				fprintf(stderr, _("%cClearing: %i percent"), 13,
 						(i + 1) * 100 / (MemStatus.MemoryUsed + MemStatus.MemoryFree));
@@ -1141,25 +1128,25 @@ void ClearAll(int argc UNUSED, char *argv[] UNUSED)
 
 	GSM_Init(true);
 
-	ClearMemory(MEM_ME, _("Delete phone phonebook"));
-	ClearMemory(MEM_SM, _("Delete SIM phonebook"));
-	ClearMemory(MEM_MC, _("Delete missed calls"));
-	ClearMemory(MEM_DC, _("Delete dialled calls"));
-	ClearMemory(MEM_RC, _("Delete received calls"));
+	ClearMemory(MEM_ME, _("Delete phone phonebook?"));
+	ClearMemory(MEM_SM, _("Delete SIM phonebook?"));
+	ClearMemory(MEM_MC, _("Delete missed calls?"));
+	ClearMemory(MEM_DC, _("Delete dialled calls?"));
+	ClearMemory(MEM_RC, _("Delete received calls?"));
 
 	DoClear = false;
-	error = GSM_GetNextCalendar(s,&Calendar,true);
+	error = GSM_GetNextCalendar(gsm,&Calendar,true);
 	if (error == ERR_NONE) {
- 		if (answer_yes(_("Delete phone calendar notes"))) DoClear = true;
+ 		if (answer_yes(_("Delete phone calendar notes?"))) DoClear = true;
 	}
 	if (DoClear) {
 		fprintf(stderr, LISTFORMAT, _("Deleting"));
-		error=GSM_DeleteAllCalendar(s);
+		error=GSM_DeleteAllCalendar(gsm);
 		if (error == ERR_NOTSUPPORTED || error == ERR_NOTIMPLEMENTED) {
  			while (1) {
-				error = GSM_GetNextCalendar(s,&Calendar,true);
+				error = GSM_GetNextCalendar(gsm,&Calendar,true);
 				if (error != ERR_NONE) break;
-				error = GSM_DeleteCalendar(s,&Calendar);
+				error = GSM_DeleteCalendar(gsm,&Calendar);
  				Print_Error(error);
 				fprintf(stderr, "*");
 			}
@@ -1171,18 +1158,18 @@ void ClearAll(int argc UNUSED, char *argv[] UNUSED)
 	}
 
 	DoClear = false;
-	error = GSM_GetToDoStatus(s,&ToDoStatus);
+	error = GSM_GetToDoStatus(gsm,&ToDoStatus);
 	if (error == ERR_NONE && ToDoStatus.Used != 0) {
-		if (answer_yes(_("Delete phone ToDo"))) DoClear = true;
+		if (answer_yes(_("Delete phone ToDo?"))) DoClear = true;
 	}
 	if (DoClear) {
 		fprintf(stderr, LISTFORMAT, _("Deleting"));
-		error=GSM_DeleteAllToDo(s);
+		error=GSM_DeleteAllToDo(gsm);
 		if (error == ERR_NOTSUPPORTED || error == ERR_NOTIMPLEMENTED) {
  			while (1) {
-				error = GSM_GetNextToDo(s,&ToDo,true);
+				error = GSM_GetNextToDo(gsm,&ToDo,true);
 				if (error != ERR_NONE) break;
-				error = GSM_DeleteToDo(s,&ToDo);
+				error = GSM_DeleteToDo(gsm,&ToDo);
  				Print_Error(error);
 				fprintf(stderr, "*");
 			}
@@ -1194,16 +1181,16 @@ void ClearAll(int argc UNUSED, char *argv[] UNUSED)
 	}
 
 	DoClear = false;
-	error = GSM_GetNotesStatus(s,&ToDoStatus);
+	error = GSM_GetNotesStatus(gsm,&ToDoStatus);
 	if (error == ERR_NONE && ToDoStatus.Used != 0) {
-		if (answer_yes(_("Delete phone Notes"))) DoClear = true;
+		if (answer_yes(_("Delete phone Notes?"))) DoClear = true;
 	}
 	if (DoClear) {
 		fprintf(stderr, LISTFORMAT, _("Deleting"));
 		while (1) {
-			error = GSM_GetNextNote(s,&Note,true);
+			error = GSM_GetNextNote(gsm,&Note,true);
 			if (error != ERR_NONE) break;
-			error = GSM_DeleteNote(s,&Note);
+			error = GSM_DeleteNote(gsm,&Note);
 			Print_Error(error);
 			fprintf(stderr, "*");
 		}
@@ -1211,9 +1198,9 @@ void ClearAll(int argc UNUSED, char *argv[] UNUSED)
 	}
 
 	Bookmark.Location = 1;
-	error = GSM_GetWAPBookmark(s,&Bookmark);
+	error = GSM_GetWAPBookmark(gsm,&Bookmark);
 	if (error == ERR_NONE || error == ERR_INVALIDLOCATION) {
-		if (answer_yes(_("Delete phone WAP bookmarks"))) {
+		if (answer_yes(_("Delete phone WAP bookmarks?"))) {
 			fprintf(stderr, LISTFORMAT, _("Deleting"));
 			/* One thing to explain: DCT4 phones seems to have bug here.
 			 * When delete for example first bookmark, phone change
@@ -1222,25 +1209,25 @@ void ClearAll(int argc UNUSED, char *argv[] UNUSED)
 			 * it later
 			 */
 			while (error==ERR_NONE) {
-				error = GSM_DeleteWAPBookmark(s,&Bookmark);
+				error = GSM_DeleteWAPBookmark(gsm,&Bookmark);
 				Bookmark.Location = 1;
-				error = GSM_GetWAPBookmark(s,&Bookmark);
+				error = GSM_GetWAPBookmark(gsm,&Bookmark);
 				fprintf(stderr, "*");
 			}
 			fprintf(stderr, "\n");
 		}
 	}
-	if (answer_yes(_("Delete all phone user ringtones"))) {
+	if (answer_yes(_("Delete all phone user ringtones?"))) {
 		fprintf(stderr, LISTFORMAT, _("Deleting"));
-		error=GSM_DeleteUserRingtones(s);
+		error=GSM_DeleteUserRingtones(gsm);
 		Print_Error(error);
 		fprintf(stderr, "%s\n", _("Done"));
 	}
 	Station.Location = 1;
-	error=GSM_GetFMStation(s,&Station);
+	error=GSM_GetFMStation(gsm,&Station);
 	if (error == ERR_NONE || error == ERR_EMPTY) {
-	 	if (answer_yes(_("Delete all phone FM radio stations"))) {
- 			error=GSM_ClearFMStations(s);
+	 	if (answer_yes(_("Delete all phone FM radio stations?"))) {
+ 			error=GSM_ClearFMStations(gsm);
  			Print_Error(error);
 		}
  	}
@@ -1343,7 +1330,7 @@ void GetSyncMLSettings(int argc, char *argv[])
 
 	for (i=start;i<=stop;i++) {
 		settings.Location=i;
-		error=GSM_GetSyncMLSettings(s,&settings);
+		error=GSM_GetSyncMLSettings(gsm,&settings);
 		Print_Error(error);
 		printf("%i. ", i);
 		if (settings.Name[0]==0 && settings.Name[1]==0) {
@@ -1352,7 +1339,6 @@ void GetSyncMLSettings(int argc, char *argv[])
 			printf("%s", DecodeUnicodeConsole(settings.Name));
 		}
 		if (settings.Active) printf(_(" (active)"));
-//		if (settings.ReadOnly) printf(_("\nRead only           : yes"));
 		printf("\n");
 		printf(LISTFORMAT "\"%s\"\n", _("User"),DecodeUnicodeConsole(settings.User));
 		printf(LISTFORMAT "\"%s\"\n", _("Password"),DecodeUnicodeConsole(settings.Password));
@@ -1393,7 +1379,7 @@ void GetChatSettings(int argc, char *argv[])
 
 	for (i=start;i<=stop;i++) {
 		settings.Location=i;
-		error=GSM_GetChatSettings(s,&settings);
+		error=GSM_GetChatSettings(gsm,&settings);
 		Print_Error(error);
 		printf("%i. ",i);
 		if (settings.Name[0]==0 && settings.Name[1]==0) {
@@ -1402,7 +1388,6 @@ void GetChatSettings(int argc, char *argv[])
 			printf("%s", DecodeUnicodeConsole(settings.Name));
 		}
 		if (settings.Active) printf(_(" (active)"));
-//		if (settings.ReadOnly) printf(_("\nRead only           : yes"));
 		printf("\n");
 		printf(LISTFORMAT "\"%s\"\n", _("Homepage"),DecodeUnicodeConsole(settings.HomePage));
 		printf(LISTFORMAT "\"%s\"\n", _("User"),DecodeUnicodeConsole(settings.User));
@@ -1434,9 +1419,9 @@ void GetWAPMMSSettings(int argc, char *argv[])
 	for (i=start;i<=stop;i++) {
 		settings.Location=i;
 		if (strcasestr(argv[1], "getwapsettings") != NULL) {
-			error=GSM_GetWAPSettings(s,&settings);
+			error=GSM_GetWAPSettings(gsm,&settings);
 		} else {
-			error=GSM_GetMMSSettings(s,&settings);
+			error=GSM_GetMMSSettings(gsm,&settings);
 		}
 		Print_Error(error);
 		for (j=0;j<settings.Number;j++) {
@@ -1530,7 +1515,7 @@ void CopyRingtone(int argc, char *argv[])
 
 void PressKeySequence(int argc UNUSED, char *argv[])
 {
-	int 		i,Length;
+	size_t i,Length;
 	GSM_KeyCode	KeyCode[500];
 	GSM_Error error;
 
@@ -1543,9 +1528,9 @@ void PressKeySequence(int argc UNUSED, char *argv[])
 	GSM_Init(true);
 
 	for (i=0;i<Length;i++) {
-		error=GSM_PressKey(s, KeyCode[i], true);
+		error=GSM_PressKey(gsm, KeyCode[i], true);
 		Print_Error(error);
-		error=GSM_PressKey(s, KeyCode[i], false);
+		error=GSM_PressKey(gsm, KeyCode[i], false);
 		Print_Error(error);
 	}
 
@@ -1572,13 +1557,13 @@ void GetAllCategories(int argc UNUSED, char *argv[])
 
 	GSM_Init(true);
 
-	error=GSM_GetCategoryStatus(s, &Status);
+	error=GSM_GetCategoryStatus(gsm, &Status);
 	Print_Error(error);
 
 	for (count=0,j=1;count<Status.Used;j++)
 	{
     		Category.Location=j;
-		error=GSM_GetCategory(s, &Category);
+		error=GSM_GetCategory(gsm, &Category);
 
 		if (error != ERR_EMPTY) {
 			printf(LISTFORMAT "%i\n", _("Location"),j);
@@ -1618,7 +1603,7 @@ void GetCategory(int argc, char *argv[])
 
 		Category.Location=j;
 
-		error=GSM_GetCategory(s, &Category);
+		error=GSM_GetCategory(gsm, &Category);
 		if (error != ERR_EMPTY) Print_Error(error);
 
 		if (error == ERR_EMPTY) {
@@ -1657,7 +1642,7 @@ void AddCategory(int argc UNUSED, char *argv[])
 
 	Category.Location = 0;
 
-	error = GSM_AddCategory(s, &Category);
+	error = GSM_AddCategory(gsm, &Category);
 
 	Print_Error(error);
 
@@ -1691,7 +1676,7 @@ void EnterSecurityCode(int argc UNUSED, char *argv[])
 
 	GSM_Init(true);
 
-	error=GSM_EnterSecurityCode(s,Code);
+	error=GSM_EnterSecurityCode(gsm,Code);
 	Print_Error(error);
 
 	GSM_Terminate();
@@ -1712,12 +1697,12 @@ void GetProfile(int argc, char *argv[])
 
 	GSM_Init(true);
 
-	error=GSM_GetRingtonesInfo(s,&Info);
+	error=GSM_GetRingtonesInfo(gsm,&Info);
 	if (error != ERR_NONE) Info.Number = 0;
 
 	for (i=start;i<=stop;i++) {
 		Profile.Location=i;
-		error=GSM_GetProfile(s,&Profile);
+		error=GSM_GetProfile(gsm,&Profile);
 		if (error != ERR_NONE && Info.Ringtone) free(Info.Ringtone);
 		Print_Error(error);
 
@@ -1752,7 +1737,7 @@ void GetProfile(int argc, char *argv[])
 						if (!callerinit[k]) {
 							caller[k].Type	 	= GSM_CallerGroupLogo;
 							caller[k].Location 	= k + 1;
-							error=GSM_GetBitmap(s,&caller[k]);
+							error=GSM_GetBitmap(gsm,&caller[k]);
 							if (error == ERR_SECURITYERROR) {
 								NOKIA_GetDefaultCallerGroupName(&caller[k]);
 							} else {
@@ -1849,7 +1834,7 @@ void GetSpeedDial(int argc, char *argv[])
 
 	for (i=start;i<=stop;i++) {
 		SpeedDial.Location=i;
-		error=GSM_GetSpeedDial(s,&SpeedDial);
+		error=GSM_GetSpeedDial(gsm,&SpeedDial);
 		printf(LISTFORMAT "%i\n", _("Location"), i);
 		switch (error) {
 		case ERR_EMPTY:
@@ -1860,7 +1845,7 @@ void GetSpeedDial(int argc, char *argv[])
 
 			Phonebook.Location	= SpeedDial.MemoryLocation;
 			Phonebook.MemoryType 	= SpeedDial.MemoryType;
-			error=GSM_GetMemory(s,&Phonebook);
+			error=GSM_GetMemory(gsm,&Phonebook);
 
 			GSM_PhonebookFindDefaultNameNumberGroup(&Phonebook, &Name, &Number, &Group);
 
@@ -1890,7 +1875,7 @@ void ResetPhoneSettings(int argc UNUSED, char *argv[])
 
 	GSM_Init(true);
 
-	error=GSM_ResetPhoneSettings(s,Type);
+	error=GSM_ResetPhoneSettings(gsm,Type);
 	Print_Error(error);
 
  	GSM_Terminate();
@@ -1901,7 +1886,7 @@ void SendDTMF(int argc UNUSED, char *argv[])
 	GSM_Error error;
 	GSM_Init(true);
 
-	error=GSM_SendDTMF(s,argv[2]);
+	error=GSM_SendDTMF(gsm,argv[2]);
 	Print_Error(error);
 
  	GSM_Terminate();
@@ -1915,7 +1900,7 @@ void GetDisplayStatus(int argc UNUSED, char *argv[] UNUSED)
 
 	GSM_Init(true);
 
-	error=GSM_GetDisplayStatus(s,&Features);
+	error=GSM_GetDisplayStatus(gsm,&Features);
 	Print_Error(error);
 
 	printf(LISTFORMAT "\n", _("Current display features"));
@@ -1940,7 +1925,7 @@ void SetAutoNetworkLogin(int argc UNUSED, char *argv[] UNUSED)
 	GSM_Error error;
 	GSM_Init(true);
 
-	error=GSM_SetAutoNetworkLogin(s);
+	error=GSM_SetAutoNetworkLogin(gsm);
 	Print_Error(error);
 
  	GSM_Terminate();
@@ -1958,7 +1943,7 @@ void GetFMStation(int argc, char *argv[])
 
 	for (i=start;i<=stop;i++) {
 		Station.Location=i;
-		error=GSM_GetFMStation(s,&Station);
+		error=GSM_GetFMStation(gsm,&Station);
 		printf(LISTFORMAT "%i\n", _("Location"), i);
 		switch (error) {
 		case ERR_EMPTY:
@@ -2009,7 +1994,7 @@ void CallDivert(int argc, char *argv[])
 	GSM_Init(true);
 
 	if (strcasecmp("get", argv[2]) == 0) {
-		error = GSM_GetCallDivert(s,&cd);
+		error = GSM_GetCallDivert(gsm,&cd);
 	    	Print_Error(error);
 		printf(_("Query:\n   Divert type: "));
 	} else {
@@ -2020,7 +2005,7 @@ void CallDivert(int argc, char *argv[])
 		cd.Request.Timeout = 0;
 		if (argc > 6) cd.Request.Timeout = atoi(argv[6]);
 
-		error = GSM_SetCallDivert(s,&cd);
+		error = GSM_SetCallDivert(gsm,&cd);
 	    	Print_Error(error);
 		printf(_("Changed:\n   Divert type: "));
 	}
@@ -2066,7 +2051,7 @@ void CancelAllDiverts(int argc UNUSED, char *argv[] UNUSED)
 	GSM_Error error;
 	GSM_Init(true);
 
-	error = GSM_CancelAllDiverts(s);
+	error = GSM_CancelAllDiverts(gsm);
     	Print_Error(error);
 
 	GSM_Terminate();
