@@ -4,7 +4,6 @@
 #include "../common/misc/locales.h"
 
 #include <gammu.h>
-#include <unistd.h>
 #include <stdlib.h>
 #include <ctype.h>
 
@@ -172,7 +171,7 @@ void NokiaSecurityCode(int argc, char *argv[])
 	DCT3GetSecurityCode(argc,argv);
 #endif
 #ifdef GSM_ENABLE_NOKIA_DCT4
-//	DCT4ResetSecurityCode(argc, argv);
+/* 	DCT4ResetSecurityCode(argc, argv); */
 	DCT4GetSecurityCode(argc,argv);
 #endif
 
@@ -231,9 +230,9 @@ void NokiaAddPlayLists2(unsigned char *ID,unsigned char *Name,unsigned char *IDF
 	CopyUnicodeString(Files.ID_FullName,ID);
 
 	printf(_("Checking %s\n"),DecodeUnicodeString(Name));
-	//looking into folder content (searching for mp3 and similiar)
+	/* looking into folder content (searching for mp3 and similiar) */
 	while (1) {
-		error = GSM_GetFolderListing(s,&Files,Start);
+		error = GSM_GetFolderListing(gsm,&Files,Start);
 		if (error == ERR_FOLDERPART) {
 			printf("%s\n", _("  Only part handled!"));
 			break;
@@ -255,7 +254,7 @@ void NokiaAddPlayLists2(unsigned char *ID,unsigned char *Name,unsigned char *IDF
 				Entry->Next = NULL;
 				Entry->Name = malloc(strlen(DecodeUnicodeString(Files.ID_FullName))+1);
 				sprintf(Entry->Name,"%s",DecodeUnicodeString(Files.ID_FullName));
-				//converting Gammu drives to phone drives
+				/* converting Gammu drives to phone drives */
 				if (Entry->Name[0]=='a' || Entry->Name[0]=='A') {
 					Entry->Name[0]='b';
 				} else if (Entry->Name[0]=='d' || Entry->Name[0]=='D') {
@@ -280,7 +279,7 @@ void NokiaAddPlayLists2(unsigned char *ID,unsigned char *Name,unsigned char *IDF
 		Start = false;
 	}
 	if (First!=NULL) {
-		//sorting songs names
+		/* sorting songs names */
 		Entry=First;
 		while (Entry->Next!=NULL) {
 			if (strcmp(Entry->NameUP,Entry->Next->NameUP)>0) {
@@ -297,14 +296,14 @@ void NokiaAddPlayLists2(unsigned char *ID,unsigned char *Name,unsigned char *IDF
 			}
 			Entry=Entry->Next;
 		}
-		//we checking, if file already exist.if yes, we look for another...
+		/* we checking, if file already exist.if yes, we look for another... */
 		i 		= 0;
 		Files3.Buffer 	= NULL;
 		while (1) {
 			CopyUnicodeString(Files3.ID_FullName,IDFolder);
 	        	CopyUnicodeString(Buffer2,Name);
 			if (i!=0) {
-				sprintf(Buffer,"" SIZE_T_FORMAT "",i);
+				sprintf(Buffer, SIZE_T_FORMAT, i);
 		        	EncodeUnicode(Buffer2+UnicodeLength(Buffer2)*2,Buffer,strlen(Buffer));
 			}
 	        	EncodeUnicode(Buffer2+UnicodeLength(Buffer2)*2,".m3u",4);
@@ -312,7 +311,7 @@ void NokiaAddPlayLists2(unsigned char *ID,unsigned char *Name,unsigned char *IDF
 			Start = true;
 			Available = false;
 			while (1) {
-				error = GSM_GetFolderListing(s,&Files3,Start);
+				error = GSM_GetFolderListing(gsm,&Files3,Start);
 				if (error == ERR_FOLDERPART) {
 					printf("%s\n", _("  Problem with adding playlist"));
 					break;
@@ -332,7 +331,7 @@ void NokiaAddPlayLists2(unsigned char *ID,unsigned char *Name,unsigned char *IDF
 			i++;
 		}
 
-		//preparing new playlist file date
+		/* preparing new playlist file date */
 		Files2.System	 = false;
 		Files2.Folder 	 = false;
 		Files2.ReadOnly	 = false;
@@ -343,7 +342,7 @@ void NokiaAddPlayLists2(unsigned char *ID,unsigned char *Name,unsigned char *IDF
 		CopyUnicodeString(Files2.ID_FullName,IDFolder);
 	        CopyUnicodeString(Files2.Name,Buffer2);
 
-		//preparing new playlist file content
+		/* preparing new playlist file content */
 		Files2.Buffer=NULL;
 		Files2.Buffer = (unsigned char *)realloc(Files2.Buffer,10);
 		sprintf(Files2.Buffer,"#EXTM3U%c%c",13,10);
@@ -360,11 +359,11 @@ void NokiaAddPlayLists2(unsigned char *ID,unsigned char *Name,unsigned char *IDF
 			if (Files2.Buffer[i]=='/') Files2.Buffer[i]='\\';
 		}
 
-		//adding new playlist file
+		/* adding new playlist file */
 		sprintf(Buffer2,"  Writing %s: ",DecodeUnicodeString(Files2.Name));
 		AddOneFile(&Files2, Buffer2, false);
 
-		//cleaning buffers
+		/* cleaning buffers */
 		free(Files2.Buffer);
 		Files2.Buffer=NULL;
 		while (Entry!=NULL) {
@@ -382,7 +381,7 @@ void NokiaAddPlayLists2(unsigned char *ID,unsigned char *Name,unsigned char *IDF
 		}
 	}
 
-	//going into subfolders
+	/* going into subfolders */
 	if (NamesPos != 0) {
 		i = 0; j = 0;
 		while (i != NamesPos) {
@@ -404,14 +403,14 @@ void NokiaAddPlayLists(int argc UNUSED, char *argv[] UNUSED)
 
 	GSM_Init(true);
 
-	//delete old playlists
+	/* delete old playlists */
 	EncodeUnicode(IDFolder,"d:\\predefplaylist",17);
 	CopyUnicodeString(Files.ID_FullName,IDFolder);
-	error = GSM_GetFolderListing(s,&Files,Start);
+	error = GSM_GetFolderListing(gsm,&Files,Start);
 	if (error == ERR_FILENOTEXIST) {
 		EncodeUnicode(IDFolder,"d:\\predefgallery\\predefplaylist",17+14);
 		CopyUnicodeString(Files.ID_FullName,IDFolder);
-		error = GSM_GetFolderListing(s,&Files,Start);
+		error = GSM_GetFolderListing(gsm,&Files,Start);
 	} else if (error != ERR_EMPTY) {
 	    	Print_Error(error);
 	}
@@ -425,12 +424,12 @@ void NokiaAddPlayLists(int argc UNUSED, char *argv[] UNUSED)
 	while (1) {
 		if (!Files.Folder) {
 			if (strstr(DecodeUnicodeConsole(Files.Name),".m3u")!=NULL) {
-				error = GSM_DeleteFile(s,Files.ID_FullName);
+				error = GSM_DeleteFile(gsm,Files.ID_FullName);
 			    	Print_Error(error);
 			}
 		}
 		Start = false;
-		error = GSM_GetFolderListing(s,&Files,Start);
+		error = GSM_GetFolderListing(gsm,&Files,Start);
 		if (error == ERR_FOLDERPART) {
 			printf("%s\n", _("Problem with deleting playlist"));
 			break;
@@ -439,11 +438,11 @@ void NokiaAddPlayLists(int argc UNUSED, char *argv[] UNUSED)
 	    	Print_Error(error);
 	}
 
-	//go over phone memory and add new one playlists
+	/* go over phone memory and add new one playlists */
 	EncodeUnicode(buffer,"d:",2);
 	EncodeUnicode(buffer2,"root",4);
 	NokiaAddPlayLists2(buffer,buffer2,IDFolder);
-	//go over memory card and add new one playlists
+	/* go over memory card and add new one playlists */
 	EncodeUnicode(buffer,"a:",2);
 	EncodeUnicode(buffer2,"root",4);
 	NokiaAddPlayLists2(buffer,buffer2,IDFolder);
@@ -472,24 +471,24 @@ struct NokiaFolderInfo Folder[] = {
 	{"", 	 "Video",	   "d:/predefgallery/predefvideos",			""},
 	{"", 	 "Playlist",	   "d:/predefplaylist",					""},
 	{"", 	 "MemoryCard",	   "a:",						""},
-	    //now values first seen in S40 3.0
+	    /* now values first seen in S40 3.0 */
 	{"",	 "Application",	   "d:/predefjava/predefcollections",			""},
 	{"",	 "Game",	   "d:/predefjava/predefgames",				""},
 
 	/* Language depedent in DCT4 filesystem 1 */
 	{"",	 "Gallery",	   "Clip-arts",					"3"},
-	{"",	 "Gallery",	   "004F006200720061007A006B0069",		"3"},//obrazki PL 6220
-	{"",	 "Gallery",	   "Pictures",					"2"},//3510
+	{"",	 "Gallery",	   "004F006200720061007A006B0069",		"3"},/* obrazki PL 6220 */
+	{"",	 "Gallery",	   "Pictures",					"2"},/* 3510 */
 	{"",	 "Gallery2",	   "Graphics",					"3"},
-	{"",	 "Gallery2",	   "00470072006100660069006B0061",		"3"},//grafika PL 6220
+	{"",	 "Gallery2",	   "00470072006100660069006B0061",		"3"},/* grafika PL 6220 */
 	{"",	 "Camera",	   "Images",					"3"},
-	{"",	 "Camera",	   "005A0064006A0119006300690061",		"3"},//zdjecia PL 6220
+	{"",	 "Camera",	   "005A0064006A0119006300690061",		"3"},/* zdjecia PL 6220 */
 	{"",	 "Tones",	   "Tones",					"3"},
-	{"",	 "Tones",	   "0044017A007700690119006B0069",		"3"},//dzwieki pl 6220
+	{"",	 "Tones",	   "0044017A007700690119006B0069",		"3"},/* dzwieki pl 6220 */
 	{"",	 "Records",	   "Recordings",				"3"},
-	{"",	 "Records",	   "004E0061006700720061006E00690061",		"3"},//nagrania pl 6220
+	{"",	 "Records",	   "004E0061006700720061006E00690061",		"3"},/* nagrania pl 6220 */
 	{"",	 "Video",	   "Video clips",				"3"},
-	{"",	 "Video",	   "0057006900640065006F006B006C006900700079",	"3"},//wideoklipy pl 6220
+	{"",	 "Video",	   "0057006900640065006F006B006C006900700079",	"3"},/* wideoklipy pl 6220 */
 
 	/* Language indepedent in OBEX */
 	{"obex", "MMSUnreadInbox", "predefMessages\\predefINBOX", 		""},
@@ -497,8 +496,8 @@ struct NokiaFolderInfo Folder[] = {
 	{"obex", "MMSOutbox",	   "predefMessages\\predefOUTBOX", 		""},
 	{"obex", "MMSSent",	   "predefMessages\\predefSENT", 		""},
 	{"obex", "MMSDrafts",	   "predefMessages\\predefDRAFTS", 		""},
-//	{"obex", "Application,	   "predefjava\\predefapplications", 		""},
-//	{"obex", "Game",	   "predefjava\\predefgames", 			""},
+/* 	{"obex", "Application,	   "predefjava\\predefapplications", 		""}, */
+/* 	{"obex", "Game",	   "predefjava\\predefgames", 			""}, */
 	{"obex", "Gallery",	   "predefgallery\\predefgraphics", 		""},
 	{"obex", "Tones",	   "predefgallery\\predeftones", 		""},
 
@@ -513,7 +512,7 @@ void NokiaAddFile(int argc, char *argv[])
 	FILE			*file;
 	unsigned char 		buffer[10000],JAR[500],Vendor[500],Name[500],Version[500],FileID[400];
 	bool 			Start = true, Found = false, wasclr;
-	bool			ModEmpty = false, Overwrite = false;
+	bool			ModEmpty = false, Overwrite = false, OverwriteAll = false;
 	size_t i = 0, Pos;
 	int Size, Size2;
 	int nextlong, j;
@@ -548,7 +547,7 @@ void NokiaAddFile(int argc, char *argv[])
 	GSM_Init(true);
 
 	Found = false;
-    	if (GSM_GetUsedConnection(s) == GCT_IRDAOBEX || GSM_GetUsedConnection(s) == GCT_BLUEOBEX) {
+    	if (GSM_GetUsedConnection(gsm) == GCT_IRDAOBEX || GSM_GetUsedConnection(gsm) == GCT_BLUEOBEX) {
 		i = 0;
 		while (Folder[i].parameter[0] != 0) {
 			if (!strcmp("obex",Folder[i].model) &&
@@ -564,14 +563,14 @@ void NokiaAddFile(int argc, char *argv[])
 			GSM_Terminate();
 			exit(-1);
 		}
-	} else if (GSM_IsPhoneFeatureAvailable(GSM_GetModelInfo(s), F_FILES2)) {
+	} else if (GSM_IsPhoneFeatureAvailable(GSM_GetModelInfo(gsm), F_FILES2)) {
 		i = 0;
 		while (Folder[i].parameter[0] != 0) {
 			if ((Folder[i].folder[0] == 'a' || Folder[i].folder[0] == 'd') &&
 			    Folder[i].level[0] == 0x00 &&
 			    strcasecmp(argv[2],Folder[i].parameter) == 0) {
 				if (strstr(Folder[i].folder,"d:/predefjava/")!= NULL &&
-				    !GSM_IsPhoneFeatureAvailable(GSM_GetModelInfo(s), F_SERIES40_30)) {
+				    !GSM_IsPhoneFeatureAvailable(GSM_GetModelInfo(gsm), F_SERIES40_30)) {
 					i++;
 					continue;
 				}
@@ -585,7 +584,7 @@ void NokiaAddFile(int argc, char *argv[])
 	if (!Found) {
 		fprintf(stderr, _("Searching for phone folder: "));
 		while (1) {
-			error = GSM_GetNextFileFolder(s,&Files,Start);
+			error = GSM_GetNextFileFolder(gsm,&Files,Start);
 			if (error == ERR_EMPTY) break;
 		    	Print_Error(error);
 
@@ -595,7 +594,7 @@ void NokiaAddFile(int argc, char *argv[])
 				i 	= 0;
 				while (Folder[i].parameter[0] != 0) {
 					EncodeUnicode(buffer,Folder[i].folder,strlen(Folder[i].folder));
-					dbgprintf("comparing \"%s\" \"%s\" \"%s\"\n",GSM_GetModelInfo(s)->model,DecodeUnicodeString(Files.ID_FullName),Folder[i].level);
+					dbgprintf("comparing \"%s\" \"%s\" \"%s\"\n",GSM_GetModelInfo(gsm)->model,DecodeUnicodeString(Files.ID_FullName),Folder[i].level);
 					if (strcasecmp(argv[2],Folder[i].parameter) == 0  &&
 					    mywstrncasecmp(Files.Name,buffer,0) &&
 					    Files.Level == atoi(Folder[i].level)) {
@@ -746,6 +745,10 @@ void NokiaAddFile(int argc, char *argv[])
 		if (argc > 4) {
 			for (j = 4; j < argc; j++) {
 				if (strcasecmp(argv[j],"-overwrite") == 0) Overwrite = true;
+				if (strcasecmp(argv[j],"-overwriteall") == 0) {
+					Overwrite = true;
+					OverwriteAll = true;
+				}
 			}
 		}
 
@@ -755,14 +758,14 @@ void NokiaAddFile(int argc, char *argv[])
 			strcat(buffer,Name);
 			EncodeUnicode(File.Name,buffer,strlen(buffer));
 			CopyUnicodeString(File.ID_FullName,Files.ID_FullName);
-			error = GSM_AddFolder(s,&File);
+			error = GSM_AddFolder(gsm,&File);
 			if (Overwrite && (error == ERR_FILEALREADYEXIST)) {
 				fprintf(stderr, "%s\n", _("INFO: Application already exist. Deleting by Gammu"));
 
 				Start = true;
 				CopyUnicodeString(File2.ID_FullName,Files.ID_FullName);
 				while (1) {
-					error = GSM_GetFolderListing(s,&File2,Start);
+					error = GSM_GetFolderListing(gsm,&File2,Start);
 					if (error == ERR_EMPTY) break;
 					Print_Error(error);
 
@@ -773,25 +776,68 @@ void NokiaAddFile(int argc, char *argv[])
 					Start = false;
 				}
 
-				CopyUnicodeString(buffer,File2.ID_FullName);
+				Start = true;
+				CopyUnicodeString(File.ID_FullName,File2.ID_FullName);
 				while (1) {
-					CopyUnicodeString(File2.ID_FullName,buffer);
-					error = GSM_GetFolderListing(s,&File2,true);
+					error = GSM_GetFolderListing(gsm,&File2,Start);
 					if (error == ERR_EMPTY) break;
 					Print_Error(error);
 
-					fprintf(stderr, _("  Deleting %s\n"),DecodeUnicodeString(File2.Name));
+					strcpy(buffer,DecodeUnicodeString(File2.Name));
 
-					error = GSM_DeleteFile(s,File2.ID_FullName);
+					i = strlen(buffer);
+					if (i < 4) continue;
+
+					i -= 4;
+
+					if (OverwriteAll ||
+					    strcmp(buffer + i,".jad") == 0 ||
+					    strcmp(buffer + i,".jar") == 0) {
+						fprintf(stderr, _("  Deleting %s\n"),buffer);
+					error = GSM_DeleteFile(gsm,File2.ID_FullName);
 					Print_Error(error);
-				}
 
-				CopyUnicodeString(File.ID_FullName,buffer);
+						CopyUnicodeString(File2.ID_FullName,File.ID_FullName);
+						Start = true;
+					} else {
+						Start = false;
+					}
+				}
 			} else {
 			    	Print_Error(error);
 			}
 			CopyUnicodeString(FileID,File.ID_FullName);
 		} else {
+			if (Overwrite) {
+				Start = true;
+				CopyUnicodeString(File2.ID_FullName,Files.ID_FullName);
+
+				fprintf(stderr, "%s\n", _("INFO: Application already exist. Deleting by Gammu"));
+
+				while (true) {
+					error = GSM_GetFolderListing(gsm,&File2,Start);
+					if (error == ERR_EMPTY) break;
+					Print_Error(error);
+
+					strcpy(buffer,DecodeUnicodeString(File2.Name));
+
+					i = strlen(Name);
+					if (strncmp(buffer,Name,i) == 0 &&
+					    (strcmp(buffer + i,".jad") == 0 ||
+					     strcmp(buffer + i,".jar") == 0 ||
+					     (strncmp(buffer + i,"\177_m_",4) == 0 && OverwriteAll))) {
+						fprintf(stderr, _("  Deleting %s\n"),buffer);
+						error = GSM_DeleteFile(gsm,File2.ID_FullName);
+						Print_Error(error);
+
+						CopyUnicodeString(File2.ID_FullName,Files.ID_FullName);
+						Start = true;
+					} else {
+						Start = false;
+					}
+				}
+			}
+
 			CopyUnicodeString(FileID,Files.ID_FullName);
 			CopyUnicodeString(File.ID_FullName,Files.ID_FullName);
 		}
