@@ -36,7 +36,7 @@ static void DecodeInputMBUS2(unsigned char rx_byte)
 
 		if (d->Msg.CheckSum[0] != rx_byte) {
 			printf("[ERROR: checksum]\n");
-			printf(" 0x%02x / 0x%04x", d->Msg.Type, d->Msg.Length);
+			printf(" 0x%02x / 0x" SIZE_T_HEX4_FORMAT, d->Msg.Type, d->Msg.Length);
 			DumpMessage(&ldi, d->Msg.Buffer, d->Msg.Length);
 			d->MsgRXState = RX_Sync;
 			return;
@@ -47,12 +47,12 @@ static void DecodeInputMBUS2(unsigned char rx_byte)
 		} else {
 			printf("Sending frame");
 		}
-		printf(" 0x%02x / 0x%04x", d->Msg.Type, d->Msg.Length);
+		printf(" 0x%02x / 0x" SIZE_T_HEX4_FORMAT, d->Msg.Type, d->Msg.Length);
 		DumpMessage(&ldi, d->Msg.Buffer, d->Msg.Length);
 		if (d->Msg.Destination != MBUS2_DEVICE_PHONE) {
-			if (s->Phone.Functions != NULL) {
-				s->Phone.Data.RequestMsg = &d->Msg;
-				s->Phone.Functions->DispatchMessage(s);
+			if (gsm->Phone.Functions != NULL) {
+				gsm->Phone.Data.RequestMsg = &d->Msg;
+				gsm->Phone.Functions->DispatchMessage(gsm);
 			}
 		}
 		d->MsgRXState = RX_Sync;
@@ -128,12 +128,12 @@ static void DecodeInputIRDA(unsigned char rx_byte)
 		} else {
 			printf("Sending frame");
 		}
-		printf(" 0x%02x / 0x%04x", d->Msg.Type, d->Msg.Length);
+		printf(" 0x%02x / 0x" SIZE_T_HEX4_FORMAT, d->Msg.Type, d->Msg.Length);
 		DumpMessage(&ldi, d->Msg.Buffer, d->Msg.Length);
 		if (d->Msg.Destination != PHONET_DEVICE_PHONE) {
-			if (s->Phone.Functions != NULL) {
-				s->Phone.Data.RequestMsg = &d->Msg;
-				s->Phone.Functions->DispatchMessage(s);
+			if (gsm->Phone.Functions != NULL) {
+				gsm->Phone.Data.RequestMsg = &d->Msg;
+				gsm->Phone.Functions->DispatchMessage(gsm);
 			}
 		}
 		d->MsgRXState = RX_Sync;
@@ -206,7 +206,7 @@ static double				VersionNum;
 
 static void prepareStateMachine()
 {
-	GSM_Phone_Data	*Phone = &(s->Phone.Data);
+	GSM_Phone_Data	*Phone = &(gsm->Phone.Data);
 
 	strcpy(Phone->IMEI,		IMEI);
 	strcpy(Phone->Model,		Model);
@@ -240,8 +240,8 @@ static void prepareStateMachine()
 	Version[0]			= 0;
 	VersionNum			= 0;
 
-	s->Phone.Functions		= NULL;
-	s->User.UserReplyFunctions	= NULL;
+	gsm->Phone.Functions		= NULL;
+	gsm->User.UserReplyFunctions	= NULL;
 	Phone->RequestID		= ID_EachFrame;
 }
 
@@ -264,14 +264,14 @@ void decodesniff(int argc, char *argv[])
 		exit(-1);
 	}
 	file = fopen(argv[3], "rb");
-	if (!file) {
+	if (file == NULL) {
 		printf("Can not open file \"%s\"\n",argv[3]);
 		exit(-1);
 	}
 	prepareStateMachine();
 	if (argc > 4) {
-		strcpy(s->CurrentConfig->Model,argv[4]);
-		error=GSM_RegisterAllPhoneModules(s);
+		strcpy(gsm->CurrentConfig->Model,argv[4]);
+		error = GSM_RegisterAllPhoneModules(gsm);
 		if (error!=ERR_NONE) Print_Error(error);
 	}
 	/* Irda uses simple "raw" format */
@@ -356,20 +356,15 @@ void decodebinarydump(int argc, char *argv[])
 
 	prepareStateMachine();
 	if (argc > 3) {
-		strcpy(s->CurrentConfig->Model,argv[3]);
-		error=GSM_RegisterAllPhoneModules(s);
+		strcpy(gsm->CurrentConfig->Model,argv[3]);
+		error = GSM_RegisterAllPhoneModules(gsm);
 		if (error!=ERR_NONE) Print_Error(error);
 	}
 	file = fopen(argv[2], "rb");
-	if (!file) {
+	if (file == NULL) {
 		printf("Can not open file \"%s\"\n",argv[2]);
 		exit(-1);
 	}
-//	len2=fread(Buffer, 1, 1, file);
-//	len2=Buffer[0];
-//	len =fread(Buffer, 1, len2, file);
-//	Buffer[len2]=0;
-//	dbgprintf("[Gammu            - version %s]\n",Buffer);
 	len2=30000;
 	msg.Buffer = NULL;
 	while (len2==30000) {
@@ -389,13 +384,13 @@ void decodebinarydump(int argc, char *argv[])
 			dbgprintf("0x%02x / 0x%04x", type, len);
 			DumpMessage(&ldi, Buffer+i, len);
 			fflush(stdout);
-			if (s->Phone.Functions != NULL && !sent) {
+			if (gsm->Phone.Functions != NULL && !sent) {
 				msg.Buffer = (unsigned char *)realloc(msg.Buffer,len);
 				memcpy(msg.Buffer,Buffer+i,len);
 				msg.Type		= type;
 				msg.Length		= len;
-				s->Phone.Data.RequestMsg = &msg;
-				s->Phone.Functions->DispatchMessage(s);
+				gsm->Phone.Data.RequestMsg = &msg;
+				gsm->Phone.Functions->DispatchMessage(gsm);
 			}
 			i = i + len;
 		}
