@@ -1,7 +1,7 @@
 /**
  * \file gammu-security.h
  * \author Michal Čihař
- * 
+ *
  * Security functions.
  */
 #ifndef __gammu_security_h
@@ -13,6 +13,8 @@
  */
 
 #include <gammu-limits.h>
+#include <gammu-error.h>
+#include <gammu-statemachine.h>
 
 /**
  * Definition of security codes.
@@ -43,7 +45,11 @@ typedef enum {
 	/**
 	 * Code not needed.
 	 */
-	SEC_None
+	SEC_None,
+	/**
+	 * Phone code needed.
+	 */
+	SEC_Phone,
 } GSM_SecurityCodeType;
 
 /**
